"""This is a wrapper module for Aspose.HTML .NET assembly"""

from typing import Any

def get_pyinstaller_hook_dirs() -> Any:
  """Function required by PyInstaller. Returns paths to module 
  PyInstaller hooks. Not intended to be called explicitly."""
    ...

from typing import List, Optional, Dict, Iterable
import aspose.pycore
import aspose.pydrawing
import aspose.html
import aspose.html.accessibility
import aspose.html.accessibility.results
import aspose.html.accessibility.saving
import aspose.html.collections
import aspose.html.converters
import aspose.html.diagnostics
import aspose.html.dom
import aspose.html.dom.attributes
import aspose.html.dom.canvas
import aspose.html.dom.css
import aspose.html.dom.events
import aspose.html.dom.mutations
import aspose.html.dom.svg
import aspose.html.dom.svg.datatypes
import aspose.html.dom.svg.events
import aspose.html.dom.svg.filters
import aspose.html.dom.svg.paths
import aspose.html.dom.svg.saving
import aspose.html.dom.traversal
import aspose.html.dom.traversal.filters
import aspose.html.dom.views
import aspose.html.dom.xpath
import aspose.html.drawing
import aspose.html.forms
import aspose.html.io
import aspose.html.loading
import aspose.html.net
import aspose.html.net.headers
import aspose.html.net.messagefilters
import aspose.html.net.messagehandlers
import aspose.html.rendering
import aspose.html.rendering.doc
import aspose.html.rendering.fonts
import aspose.html.rendering.image
import aspose.html.rendering.pdf
import aspose.html.rendering.pdf.encryption
import aspose.html.rendering.xps
import aspose.html.saving
import aspose.html.saving.resourcehandlers
import aspose.html.services
import aspose.html.toolkit
import aspose.html.toolkit.markdown
import aspose.html.toolkit.markdown.syntax
import aspose.html.toolkit.markdown.syntax.extensions
import aspose.html.toolkit.markdown.syntax.parser
import aspose.html.toolkit.markdown.syntax.parser.extensions
import aspose.html.toolkit.markdown.syntax.parser.extensions.gfm
import aspose.html.toolkit.markdown.syntax.text
import aspose.html.toolkit.optimizers
import aspose.html.window

class ArrayBuffer(aspose.html.dom.DOMObject):
    '''The ArrayBuffer object is used to represent a generic, fixed-length raw binary data buffer.'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    @property
    def byte_length(self) -> int:
        ...
    
    def __getitem__(self, key : int) -> byte:
        '''Gets or sets the :py:class:`int` at the specified index.'''
        ...
    
    def __setitem__(self, key : int, value : byte):
        ...
    
    ...

class Configuration:
    '''Represents the configuration context object that is used to set up the environment settings for the application.'''
    
    @staticmethod
    def create() -> aspose.html.Configuration:
        '''Create and configure the instance of Configuration object.
        
        :returns: The instance of Configuration object.'''
        ...
    
    def get_service(self, service_type : Type) -> any:
        ...
    
    @property
    def security(self) -> aspose.html.Sandbox:
        '''Gets the sandboxing flag of the configuration.'''
        ...
    
    @security.setter
    def security(self, value : aspose.html.Sandbox):
        '''Sets the sandboxing flag of the configuration.'''
        ...
    
    ...

class Float32Array(TypedArray):
    '''Represents an array of 32-bit floating point numbers (corresponding to the C float data type) in the platform byte order.'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    @property
    def buffer(self) -> aspose.html.ArrayBuffer:
        '''Gets the ArrayBuffer referenced by this instance.'''
        ...
    
    @property
    def byte_length(self) -> int:
        ...
    
    @property
    def byte_offset(self) -> int:
        ...
    
    @property
    def length(self) -> int:
        '''Gets the length of a typed array.'''
        ...
    
    @classmethod
    @property
    def BYTES_PER_ELEMENT(cls) -> byte:
        '''The property represents the size in bytes of each element in an typed array.'''
        ...
    
    def __getitem__(self, key : int) -> float:
        '''Gets or sets the :py:class:`float` at the specified index.'''
        ...
    
    def __setitem__(self, key : int, value : float):
        ...
    
    ...

class Float64Array(TypedArray):
    '''Represents an array of 64-bit floating point numbers (corresponding to the C float data type) in the platform byte order.'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    @property
    def buffer(self) -> aspose.html.ArrayBuffer:
        '''Gets the ArrayBuffer referenced by this instance.'''
        ...
    
    @property
    def byte_length(self) -> int:
        ...
    
    @property
    def byte_offset(self) -> int:
        ...
    
    @property
    def length(self) -> int:
        '''Gets the length of a typed array.'''
        ...
    
    @classmethod
    @property
    def BYTES_PER_ELEMENT(cls) -> byte:
        '''The property represents the size in bytes of each element in an typed array.'''
        ...
    
    def __getitem__(self, key : int) -> float:
        '''Gets or sets the :py:class:`float` at the specified index.'''
        ...
    
    def __setitem__(self, key : int, value : float):
        ...
    
    ...

class FontsSettings:
    '''Represents fonts handling settings.'''
    
    @overload
    def set_fonts_lookup_folder(self, fonts_folder : str):
        '''Sets folder used during fonts selection.
        
        :param fonts_folder: The fonts folder.'''
        ...
    
    @overload
    def set_fonts_lookup_folder(self, fonts_folder : str, recursive : bool):
        '''Sets folder used during fonts selection.
        
        :param fonts_folder: The fonts folder.
        :param recursive: If set to ``true`` all nested directories will be used. Default value is ``false``.'''
        ...
    
    @overload
    def set_fonts_lookup_folders(self, fonts_folders : List[str]):
        '''Sets an array of folders used during fonts selection.
        
        :param fonts_folders: The fonts folders.'''
        ...
    
    @overload
    def set_fonts_lookup_folders(self, fonts_folders : List[str], recursive : bool):
        '''Sets an array of folders used during fonts selection.
        
        :param fonts_folders: The fonts folders.
        :param recursive: If set to ``true`` all nested directories will be used. Default value is ``false``.'''
        ...
    
    def get_fonts_lookup_folders(self) -> List[str]:
        '''Gets a copy of array which contains fonts folders. Fonts found in these folders are used for characters rendering.
        
        :returns: A copy of fonts folders array.'''
        ...
    
    @property
    def font_matcher(self) -> aspose.html.rendering.fonts.FontMatcher:
        ...
    
    @font_matcher.setter
    def font_matcher(self, value : aspose.html.rendering.fonts.FontMatcher):
        ...
    
    ...

class HTMLAddressElement(HTMLElement):
    '''The address element. See the ADDRESS  element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    ...

class HTMLAnchorElement(HTMLElement):
    '''The anchor element. See the A element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    def blur(self):
        '''Removes keyboard focus from this element.'''
        ...
    
    def focus(self):
        '''Gives keyboard focus to this element.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def rel_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def access_key(self) -> str:
        ...
    
    @access_key.setter
    def access_key(self, value : str):
        ...
    
    @property
    def charset(self) -> str:
        '''The character encoding of the linked resource. See the charset
        attribute definition in HTML 4.01.'''
        ...
    
    @charset.setter
    def charset(self, value : str):
        '''The character encoding of the linked resource. See the charset
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def coords(self) -> str:
        '''Comma-separated list of lengths, defining an active region geometry.
        See also ``shape`` for the shape of the region. See the
        coords attribute definition in HTML 4.01.'''
        ...
    
    @coords.setter
    def coords(self, value : str):
        '''Comma-separated list of lengths, defining an active region geometry.
        See also ``shape`` for the shape of the region. See the
        coords attribute definition in HTML 4.01.'''
        ...
    
    @property
    def href(self) -> str:
        '''The absolute URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] of the linked resource. See the href attribute
        definition in HTML 4.01.'''
        ...
    
    @href.setter
    def href(self, value : str):
        '''The absolute URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] of the linked resource. See the href attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def hreflang(self) -> str:
        '''Language code of the linked resource. See the hreflang attribute
        definition in HTML 4.01.'''
        ...
    
    @hreflang.setter
    def hreflang(self, value : str):
        '''Language code of the linked resource. See the hreflang attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def name(self) -> str:
        '''Anchor name. See the name attribute definition in HTML 4.01.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''Anchor name. See the name attribute definition in HTML 4.01.'''
        ...
    
    @property
    def rel(self) -> str:
        '''Forward link type. See the rel attribute definition in HTML 4.01.'''
        ...
    
    @rel.setter
    def rel(self, value : str):
        '''Forward link type. See the rel attribute definition in HTML 4.01.'''
        ...
    
    @property
    def rev(self) -> str:
        '''Reverse link type. See the rev attribute definition in HTML 4.01.'''
        ...
    
    @rev.setter
    def rev(self, value : str):
        '''Reverse link type. See the rev attribute definition in HTML 4.01.'''
        ...
    
    @property
    def shape(self) -> str:
        '''The shape of the active area. The coordinates are given by
        ``coords``. See the shape attribute definition in HTML 4.01.'''
        ...
    
    @shape.setter
    def shape(self, value : str):
        '''The shape of the active area. The coordinates are given by
        ``coords``. See the shape attribute definition in HTML 4.01.'''
        ...
    
    @property
    def tab_index(self) -> int:
        ...
    
    @tab_index.setter
    def tab_index(self, value : int):
        ...
    
    @property
    def target(self) -> str:
        '''Frame to render the resource in. See the target attribute definition in
        HTML 4.01.'''
        ...
    
    @target.setter
    def target(self, value : str):
        '''Frame to render the resource in. See the target attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def type(self) -> str:
        '''Advisory content type. See the type attribute definition in HTML 4.01.'''
        ...
    
    @type.setter
    def type(self, value : str):
        '''Advisory content type. See the type attribute definition in HTML 4.01.'''
        ...
    
    @property
    def origin(self) -> str:
        '''Gets a string representation of the origin segment of the associated URL.'''
        ...
    
    @property
    def protocol(self) -> str:
        '''Gets a string representation of the scheme segment of the associated URL.'''
        ...
    
    @protocol.setter
    def protocol(self, value : str):
        '''Sets a string representation of the scheme segment of the associated URL.'''
        ...
    
    @property
    def username(self) -> str:
        '''Gets a string representation of the username segment of the associated URL.'''
        ...
    
    @username.setter
    def username(self, value : str):
        '''Sets a string representation of the username segment of the associated URL.'''
        ...
    
    @property
    def password(self) -> str:
        '''Gets a string representation of the password segment of the associated URL.'''
        ...
    
    @password.setter
    def password(self, value : str):
        '''Sets a string representation of the password segment of the associated URL.'''
        ...
    
    @property
    def host(self) -> str:
        '''Gets a string representation of the host and port segments of the associated URL.'''
        ...
    
    @host.setter
    def host(self, value : str):
        '''Sets a string representation of the host and port segments of the associated URL.'''
        ...
    
    @property
    def hostname(self) -> str:
        '''Gets a string representation of the host segment of the associated URL.'''
        ...
    
    @hostname.setter
    def hostname(self, value : str):
        '''Sets a string representation of the host segment of the associated URL.'''
        ...
    
    @property
    def port(self) -> str:
        '''Gets a string representation of the port segment of the associated URL.'''
        ...
    
    @port.setter
    def port(self, value : str):
        '''Sets a string representation of the port segment of the associated URL.'''
        ...
    
    @property
    def pathname(self) -> str:
        '''Gets a string representation of the path segment of the associated URL.'''
        ...
    
    @pathname.setter
    def pathname(self, value : str):
        '''Sets a string representation of the path segment of the associated URL.'''
        ...
    
    @property
    def search(self) -> str:
        '''Gets a string representation of the search segment of the associated URL.'''
        ...
    
    @search.setter
    def search(self, value : str):
        '''Sets a string representation of the search segment of the associated URL.'''
        ...
    
    @property
    def hash(self) -> str:
        '''Gets a string representation of the hash segment of the associated URL.'''
        ...
    
    @hash.setter
    def hash(self, value : str):
        '''Sets a string representation of the hash segment of the associated URL.'''
        ...
    
    ...

class HTMLAppletElement(HTMLElement):
    '''An embedded Java applet. See the APPLET element definition in HTML 4.01.
    This element is deprecated in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def align(self) -> str:
        '''Aligns this object (vertically or horizontally) with respect to its
        surrounding text. See the align attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Aligns this object (vertically or horizontally) with respect to its
        surrounding text. See the align attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def alt(self) -> str:
        '''Alternate text for user agents not rendering the normal content of this
        element. See the alt attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @alt.setter
    def alt(self, value : str):
        '''Alternate text for user agents not rendering the normal content of this
        element. See the alt attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def archive(self) -> str:
        '''Comma-separated archive list. See the archive attribute definition in
        HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @archive.setter
    def archive(self, value : str):
        '''Comma-separated archive list. See the archive attribute definition in
        HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def code(self) -> str:
        '''Applet class file. See the code attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @code.setter
    def code(self, value : str):
        '''Applet class file. See the code attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def code_base(self) -> str:
        ...
    
    @code_base.setter
    def code_base(self, value : str):
        ...
    
    @property
    def height(self) -> str:
        '''Override height. See the height attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @height.setter
    def height(self, value : str):
        '''Override height. See the height attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def hspace(self) -> int:
        '''Horizontal space, in pixels, to the left and right of this image,
        applet, or object. See the hspace attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.
        @version DOM Level 2'''
        ...
    
    @hspace.setter
    def hspace(self, value : int):
        '''Horizontal space, in pixels, to the left and right of this image,
        applet, or object. See the hspace attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.
        @version DOM Level 2'''
        ...
    
    @property
    def name(self) -> str:
        '''The name of the applet. See the name attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''The name of the applet. See the name attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def object(self) -> str:
        '''The value of the "object" attribute. See the object attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.
        @version DOM Level 2'''
        ...
    
    @object.setter
    def object(self, value : str):
        '''The value of the "object" attribute. See the object attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.
        @version DOM Level 2'''
        ...
    
    @property
    def vspace(self) -> int:
        '''Vertical space, in pixels, above and below this image, applet, or
        object. See the vspace attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.
        @version DOM Level 2'''
        ...
    
    @vspace.setter
    def vspace(self, value : int):
        '''Vertical space, in pixels, above and below this image, applet, or
        object. See the vspace attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.
        @version DOM Level 2'''
        ...
    
    @property
    def width(self) -> str:
        '''Override width. See the width attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @width.setter
    def width(self, value : str):
        '''Override width. See the width attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLAreaElement(HTMLElement):
    '''Client-side image map area definition. See the AREA element definition in
    HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def rel_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def access_key(self) -> str:
        ...
    
    @access_key.setter
    def access_key(self, value : str):
        ...
    
    @property
    def alt(self) -> str:
        '''Alternate text for user agents not rendering the normal content of this
        element. See the alt attribute definition in HTML 4.01.'''
        ...
    
    @alt.setter
    def alt(self, value : str):
        '''Alternate text for user agents not rendering the normal content of this
        element. See the alt attribute definition in HTML 4.01.'''
        ...
    
    @property
    def coords(self) -> str:
        '''Comma-separated list of lengths, defining an active region geometry.
        See also ``shape`` for the shape of the region. See the
        coords attribute definition in HTML 4.01.'''
        ...
    
    @coords.setter
    def coords(self, value : str):
        '''Comma-separated list of lengths, defining an active region geometry.
        See also ``shape`` for the shape of the region. See the
        coords attribute definition in HTML 4.01.'''
        ...
    
    @property
    def href(self) -> str:
        '''The URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] of the linked resource.
        See the href attribute definition in HTML 4.01.'''
        ...
    
    @href.setter
    def href(self, value : str):
        '''The URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] of the linked resource.
        See the href attribute definition in HTML 4.01.'''
        ...
    
    @property
    def no_href(self) -> bool:
        ...
    
    @no_href.setter
    def no_href(self, value : bool):
        ...
    
    @property
    def shape(self) -> str:
        '''The shape of the active area. The coordinates are given by
        ``coords``. See the shape attribute definition in HTML 4.01.'''
        ...
    
    @shape.setter
    def shape(self, value : str):
        '''The shape of the active area. The coordinates are given by
        ``coords``. See the shape attribute definition in HTML 4.01.'''
        ...
    
    @property
    def tab_index(self) -> int:
        ...
    
    @tab_index.setter
    def tab_index(self, value : int):
        ...
    
    @property
    def target(self) -> str:
        '''Frame to render the resource in. See the target attribute definition in
        HTML 4.01.'''
        ...
    
    @target.setter
    def target(self, value : str):
        '''Frame to render the resource in. See the target attribute definition in
        HTML 4.01.'''
        ...
    
    ...

class HTMLBRElement(HTMLElement):
    '''Force a line break. See the BR element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def clear(self) -> str:
        '''Control flow of text around floats. See the clear attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @clear.setter
    def clear(self, value : str):
        '''Control flow of text around floats. See the clear attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLBaseElement(HTMLElement):
    '''Document base URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`]. See the BASE element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def href(self) -> str:
        '''The base URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`]. See the href attribute definition in HTML 4.01.'''
        ...
    
    @href.setter
    def href(self, value : str):
        '''The base URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`]. See the href attribute definition in HTML 4.01.'''
        ...
    
    @property
    def target(self) -> str:
        '''The default target frame. See the target attribute definition in HTML
        4.01.'''
        ...
    
    @target.setter
    def target(self, value : str):
        '''The default target frame. See the target attribute definition in HTML
        4.01.'''
        ...
    
    ...

class HTMLBaseFontElement(HTMLElement):
    '''Base font. See the BASEFONT element definition in HTML 4.01. This element
    is deprecated in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def color(self) -> str:
        '''Font color. See the color attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @color.setter
    def color(self, value : str):
        '''Font color. See the color attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def face(self) -> str:
        '''Font face identifier. See the face attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @face.setter
    def face(self, value : str):
        '''Font face identifier. See the face attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def size(self) -> int:
        '''Computed font size. See the size attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.
        @version DOM Level 2'''
        ...
    
    @size.setter
    def size(self, value : int):
        '''Computed font size. See the size attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.
        @version DOM Level 2'''
        ...
    
    ...

class HTMLBodyElement(HTMLElement):
    '''The HTML document body. This element is always present in the DOM API, even
    if the tags are not present in the source document. See the BODY element
    definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def a_link(self) -> str:
        ...
    
    @a_link.setter
    def a_link(self, value : str):
        ...
    
    @property
    def background(self) -> str:
        '''URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] of the background texture tile image. See the background attribute
        definition in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @background.setter
    def background(self, value : str):
        '''URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] of the background texture tile image. See the background attribute
        definition in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def bg_color(self) -> str:
        ...
    
    @bg_color.setter
    def bg_color(self, value : str):
        ...
    
    @property
    def link(self) -> str:
        '''Color of links that are not active and unvisited. See the link
        attribute definition in HTML 4.01. This attribute is deprecated in
        HTML 4.01.'''
        ...
    
    @link.setter
    def link(self, value : str):
        '''Color of links that are not active and unvisited. See the link
        attribute definition in HTML 4.01. This attribute is deprecated in
        HTML 4.01.'''
        ...
    
    @property
    def text(self) -> str:
        '''Document text color. See the text attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @text.setter
    def text(self, value : str):
        '''Document text color. See the text attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def v_link(self) -> str:
        ...
    
    @v_link.setter
    def v_link(self, value : str):
        ...
    
    ...

class HTMLButtonElement(HTMLElement):
    '''Push button. See the BUTTON element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def form(self) -> aspose.html.HTMLFormElement:
        '''Returns the ``FORM`` element containing this control. Returns
        ``null`` if this control is not within the context of a
        form.'''
        ...
    
    @property
    def access_key(self) -> str:
        ...
    
    @access_key.setter
    def access_key(self, value : str):
        ...
    
    @property
    def disabled(self) -> bool:
        '''The control is unavailable in this context. See the disabled attribute
        definition in HTML 4.01.'''
        ...
    
    @disabled.setter
    def disabled(self, value : bool):
        '''The control is unavailable in this context. See the disabled attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def name(self) -> str:
        '''Form control or object name when submitted with a form. See the name
        attribute definition in HTML 4.01.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''Form control or object name when submitted with a form. See the name
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def tab_index(self) -> int:
        ...
    
    @tab_index.setter
    def tab_index(self, value : int):
        ...
    
    @property
    def type(self) -> str:
        '''The type of button (all lower case). See the type attribute definition
        in HTML 4.01.'''
        ...
    
    @type.setter
    def type(self, value : str):
        '''The type of button (all lower case). See the type attribute definition
        in HTML 4.01.'''
        ...
    
    @property
    def value(self) -> str:
        '''The current form control value. See the value attribute definition in
        HTML 4.01.'''
        ...
    
    @value.setter
    def value(self, value : str):
        '''The current form control value. See the value attribute definition in
        HTML 4.01.'''
        ...
    
    ...

class HTMLCanvasElement(HTMLElement):
    '''The HTMLCanvasElement interface provides properties and methods for manipulating the layout and presentation of canvas elements.
    The HTMLCanvasElement interface also inherits the properties and methods of the HTMLElement interface.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def to_data_url(self) -> str:
        '''returns a data URI containing a representation of the image in the format specified by the type parameter (defaults to PNG).
        The returned image is in a resolution of 96 dpi.
        
        :returns: A DOMString containing the requested data URI.'''
        ...
    
    @overload
    def to_data_url(self, type : str) -> str:
        '''returns a data URI containing a representation of the image in the format specified by the type parameter (defaults to PNG).
        The returned image is in a resolution of 96 dpi.
        
        :param type: A string indicating the image format. The default format type is image/png.
        :returns: A DOMString containing the requested data URI.'''
        ...
    
    @overload
    def to_data_url(self, type : str, encoder_options : float) -> str:
        '''returns a data URI containing a representation of the image in the format specified by the type parameter (defaults to PNG).
        The returned image is in a resolution of 96 dpi.
        
        :param type: A string indicating the image format. The default format type is image/png.
        :param encoder_options: A Number between 0 and 1 indicating image quality if the requested type is image/jpeg or image/webp.
        :returns: A DOMString containing the requested data URI.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    def get_context(self, context_id : str) -> any:
        '''Returns a drawing context on the canvas, or null if the context ID is not supported. A drawing context lets you draw on the canvas.
        
        :param context_id: Is a string containing the context identifier defining the drawing context associated to the canvas
        :returns: A RenderingContext'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def width(self) -> int:
        '''Is a positive integer reflecting the width HTML attribute of the canvas element interpreted in CSS pixels.
        When the attribute is not specified, or if it is set to an invalid value, like a negative, the default value of 300 is used.'''
        ...
    
    @width.setter
    def width(self, value : int):
        '''Is a positive integer reflecting the width HTML attribute of the canvas element interpreted in CSS pixels.
        When the attribute is not specified, or if it is set to an invalid value, like a negative, the default value of 300 is used.'''
        ...
    
    @property
    def height(self) -> int:
        '''Is a positive integer reflecting the height HTML attribute of the canvas element interpreted in CSS pixels.
        When the attribute is not specified, or if it is set to an invalid value, like a negative,
        the default value of 150 is used.'''
        ...
    
    @height.setter
    def height(self, value : int):
        '''Is a positive integer reflecting the height HTML attribute of the canvas element interpreted in CSS pixels.
        When the attribute is not specified, or if it is set to an invalid value, like a negative,
        the default value of 150 is used.'''
        ...
    
    ...

class HTMLDListElement(HTMLElement):
    '''Definition list. See the DL element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def compact(self) -> bool:
        '''Reduce spacing between list items. See the compact attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @compact.setter
    def compact(self, value : bool):
        '''Reduce spacing between list items. See the compact attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLDataListElement(HTMLElement):
    '''The datalist element represents a set of option elements that represent predefined options for other controls.
    See also the `HTML 5.2 W3C Recommendation <https://www.w3.org/TR/html52/sec-forms.html#elementdef-datalist>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def options(self) -> aspose.html.collections.HTMLCollection:
        '''The collection of ``OPTION`` elements contained by this
        element.'''
        ...
    
    ...

class HTMLDirectoryElement(HTMLElement):
    '''Directory list. See the DIR element definition in HTML 4.01. This element
    is deprecated in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def compact(self) -> bool:
        '''Reduce spacing between list items. See the compact attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @compact.setter
    def compact(self, value : bool):
        '''Reduce spacing between list items. See the compact attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLDivElement(HTMLElement):
    '''Generic block container. See the DIV element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def align(self) -> str:
        '''Horizontal text alignment. See the align attribute definition in HTML
        4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Horizontal text alignment. See the align attribute definition in HTML
        4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLDocument(aspose.html.dom.Document):
    '''An ``HTMLDocument`` is the root of the HTML hierarchy and holds
    the entire content. Besides providing access to the hierarchy, it also
    provides some convenience methods for accessing certain sets of
    information from the document.
    
    The following properties have been deprecated in favor of the
    corresponding ones for the ``BODY`` element.
    In DOM Level 2, the method ``getElementById`` is inherited from the ``Document``
    interface where it was moved to.
    
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def navigate(self, address : str):
        '''Loads the document at the specified Uniform Resource Locator (URL) into the current instance, replacing the previous content.
        
        :param address: The document address. It will be combined with the current directory path to form an absolute URL.'''
        ...
    
    @overload
    def navigate(self, url : aspose.html.Url):
        '''Loads the document at the specified Uniform Resource Locator (URL) into the current instance, replacing the previous content.
        
        :param url: The document URL.'''
        ...
    
    @overload
    def navigate(self, content : str, base_uri : str):
        '''Loads the document from specified content and using baseUri to resolve relative resources, replacing the previous content.
        
        :param content: The document content.
        :param base_uri: The base URI to resolve relative resources. It will be combined with the current directory path to form an absolute URL.'''
        ...
    
    @overload
    def navigate(self, content : str, base_uri : aspose.html.Url):
        '''Loads the document from specified content and using baseUri to resolve relative resources, replacing the previous content.
        
        :param content: The document content.
        :param base_uri: The base URI to resolve relative resources.'''
        ...
    
    @overload
    def navigate(self, content : io.RawIOBase, base_uri : str):
        '''Loads the document from specified content and using baseUri to resolve relative resources, replacing the previous content.
        Document loading starts from the current position in the stream.
        
        :param content: The document content.
        :param base_uri: The base URI to resolve relative resources. It will be combined with the current directory path to form an absolute URL.'''
        ...
    
    @overload
    def navigate(self, content : io.RawIOBase, base_uri : aspose.html.Url):
        '''Loads the document from specified content and using baseUri to resolve relative resources, replacing the previous content.
        Document loading starts from the current position in the stream.
        
        :param content: The document content.
        :param base_uri: The base URI to resolve relative resources.'''
        ...
    
    @overload
    def navigate(self, request : aspose.html.net.RequestMessage):
        '''Loads the document based on specified request object, replacing the previous content.
        
        :param request: The request object that is used to load document content.'''
        ...
    
    @overload
    def create_node_iterator(self, root : aspose.html.dom.Node) -> aspose.html.dom.traversal.INodeIterator:
        '''Create a new NodeIterator over the subtree rooted at the
        specified node.
        
        :param root: node which will be iterated together with its children.
        The iterator is initially positioned just before this node. The
        whatToShow flags and the filter, if any, are not
        considered when setting this position. The root must not be
        null.
        :returns: The newly created NodeIterator.'''
        ...
    
    @overload
    def create_node_iterator(self, root : aspose.html.dom.Node, what_to_show : int) -> aspose.html.dom.traversal.INodeIterator:
        '''Create a new NodeIterator over the subtree rooted at the
        specified node.
        
        :param root: node which will be iterated together with its children.
        The iterator is initially positioned just before this node. The
        whatToShow flags and the filter, if any, are not
        considered when setting this position. The root must not be
        null.
        :param what_to_show: flag specifies which node types may appear in
        the logical view of the tree presented by the iterator. See the
        description of NodeFilter for the set of possible
        SHOW_ values.These flags can be combined using
        OR.
        :returns: The newly created NodeIterator.'''
        ...
    
    @overload
    def create_node_iterator(self, root : aspose.html.dom.Node, what_to_show : int, filter : aspose.html.dom.traversal.INodeFilter) -> aspose.html.dom.traversal.INodeIterator:
        '''Create a new NodeIterator over the subtree rooted at the
        specified node.
        
        :param root: node which will be iterated together with its children.
        The iterator is initially positioned just before this node. The
        whatToShow flags and the filter, if any, are not
        considered when setting this position. The root must not be
        null.
        :param what_to_show: flag specifies which node types may appear in
        the logical view of the tree presented by the iterator. See the
        description of NodeFilter for the set of possible
        SHOW_ values.These flags can be combined using
        OR.
        :param filter: NodeFilter to be used with this
        TreeWalker, or null to indicate no filter.
        :returns: The newly created NodeIterator.'''
        ...
    
    @overload
    def create_tree_walker(self, root : aspose.html.dom.Node) -> aspose.html.dom.traversal.ITreeWalker:
        '''Create a new TreeWalker over the subtree rooted at the
        specified node.
        
        :param root: node which will serve as the root for the
        TreeWalker. The whatToShow flags and the
        NodeFilter are not considered when setting this value;
        any node type will be accepted as the root. The
        currentNode of the TreeWalker is
        initialized to this node, whether or not it is visible. The
        root functions as a stopping point for traversal
        methods that look upward in the document structure, such as
        parentNode and nextNode. The root must
        not be null.
        :returns: The newly created TreeWalker.'''
        ...
    
    @overload
    def create_tree_walker(self, root : aspose.html.dom.Node, what_to_show : int) -> aspose.html.dom.traversal.ITreeWalker:
        '''Create a new TreeWalker over the subtree rooted at the
        specified node.
        
        :param root: node which will serve as the root for the
        TreeWalker. The whatToShow flags and the
        NodeFilter are not considered when setting this value;
        any node type will be accepted as the root. The
        currentNode of the TreeWalker is
        initialized to this node, whether or not it is visible. The
        root functions as a stopping point for traversal
        methods that look upward in the document structure, such as
        parentNode and nextNode. The root must
        not be null.
        :param what_to_show: flag specifies which node types may appear in
        the logical view of the tree presented by the tree-walker. See the
        description of NodeFilter for the set of possible
        SHOW_ values.These flags can be combined using OR.
        :returns: The newly created TreeWalker.'''
        ...
    
    @overload
    def create_tree_walker(self, root : aspose.html.dom.Node, what_to_show : int, filter : aspose.html.dom.traversal.INodeFilter) -> aspose.html.dom.traversal.ITreeWalker:
        '''Create a new TreeWalker over the subtree rooted at the
        specified node.
        
        :param root: node which will serve as the root for the
        TreeWalker. The whatToShow flags and the
        NodeFilter are not considered when setting this value;
        any node type will be accepted as the root. The
        currentNode of the TreeWalker is
        initialized to this node, whether or not it is visible. The
        root functions as a stopping point for traversal
        methods that look upward in the document structure, such as
        parentNode and nextNode. The root must
        not be null.
        :param what_to_show: flag specifies which node types may appear in
        the logical view of the tree presented by the tree-walker. See the
        description of NodeFilter for the set of possible
        SHOW_ values.These flags can be combined using OR.
        :param filter: NodeFilter to be used with this
        TreeWalker, or null to indicate no filter.
        :returns: The newly created TreeWalker.'''
        ...
    
    @overload
    def save(self, url : aspose.html.Url):
        '''Saves the document to local file specified by ``url``. All resources used in this document will be saved in
        to adjacent folder, whose name will be constructed as: output_file_name + "_files".
        
        :param url: Local URL to output file.'''
        ...
    
    @overload
    def save(self, resource_handler : aspose.html.saving.resourcehandlers.ResourceHandler):
        '''Saves the document content and resources using the :py:class:`aspose.html.saving.resourcehandlers.ResourceHandler`.
        
        :param resource_handler: The resource handler :py:class:`aspose.html.saving.resourcehandlers.ResourceHandler`.'''
        ...
    
    @overload
    def save(self, path : str):
        '''Saves the document to local file specified by ``path``. All resources used in this document will be saved in
        to adjacent folder, whose name will be constructed as: output_file_name + "_files".
        
        :param path: Local path to output file.'''
        ...
    
    @overload
    def save(self, path : str, save_format : aspose.html.saving.HTMLSaveFormat):
        '''Saves the document to local file specified by ``path``. All resources used in this document will be saved in
        to adjacent folder, whose name will be constructed as: output_file_name + "_files".
        
        :param path: Local path to output file.
        :param save_format: Format in which document is saved.'''
        ...
    
    @overload
    def save(self, url : aspose.html.Url, save_format : aspose.html.saving.HTMLSaveFormat):
        '''Saves the document to local file specified by ``url``. All resources used in this document will be saved in
        to adjacent folder, whose name will be constructed as: output_file_name + "_files".
        
        :param url: Local URL to output file.
        :param save_format: Format in which document is saved.'''
        ...
    
    @overload
    def save(self, resource_handler : aspose.html.saving.resourcehandlers.ResourceHandler, save_format : aspose.html.saving.HTMLSaveFormat):
        '''Saves the document content and resources using the :py:class:`aspose.html.saving.resourcehandlers.ResourceHandler`.
        
        :param resource_handler: The resource handler :py:class:`aspose.html.saving.resourcehandlers.ResourceHandler`.
        :param save_format: Format in which document is saved.'''
        ...
    
    @overload
    def save(self, path : str, save_options : aspose.html.saving.HTMLSaveOptions):
        '''Saves the document to local file specified by ``path``. All resources used in this document will be saved in
        to adjacent folder, whose name will be constructed as: output_file_name + "_files".
        
        :param path: Local path to output file.
        :param save_options: HTML save options.'''
        ...
    
    @overload
    def save(self, url : aspose.html.Url, save_options : aspose.html.saving.HTMLSaveOptions):
        '''Saves the document to local file specified by ``url``. All resources used in this document will be saved in
        to adjacent folder, whose name will be constructed as: output_file_name + "_files".
        
        :param url: Local URL to output file.
        :param save_options: HTML save options.'''
        ...
    
    @overload
    def save(self, resource_handler : aspose.html.saving.resourcehandlers.ResourceHandler, save_options : aspose.html.saving.HTMLSaveOptions):
        '''Saves the document content and resources using the :py:class:`aspose.html.saving.resourcehandlers.ResourceHandler`.
        
        :param resource_handler: The resource handler :py:class:`aspose.html.saving.resourcehandlers.ResourceHandler`.
        :param save_options: HTML save options.'''
        ...
    
    @overload
    def save(self, path : str, save_options : aspose.html.saving.MarkdownSaveOptions):
        '''Saves the document to local file specified by ``path``. All resources used in this document will be saved in
        to adjacent folder, whose name will be constructed as: output_file_name + "_files".
        
        :param path: Local path to output file.
        :param save_options: Markdown save options.'''
        ...
    
    @overload
    def save(self, url : aspose.html.Url, save_options : aspose.html.saving.MarkdownSaveOptions):
        '''Saves the document to local file specified by ``url``. All resources used in this document will be saved in
        to adjacent folder, whose name will be constructed as: output_file_name + "_files".
        
        :param url: Local URL to output file.
        :param save_options: Markdown save options.'''
        ...
    
    @overload
    def save(self, resource_handler : aspose.html.saving.resourcehandlers.ResourceHandler, save_options : aspose.html.saving.MarkdownSaveOptions):
        '''Saves the document content and resources using the :py:class:`aspose.html.saving.resourcehandlers.ResourceHandler`.
        
        :param resource_handler: The resource handler :py:class:`aspose.html.saving.resourcehandlers.ResourceHandler`.
        :param save_options: Markdown save options.'''
        ...
    
    @overload
    def save(self, path : str, save_options : aspose.html.saving.MHTMLSaveOptions):
        '''Saves the document to local file specified by ``path``. All resources used in this document will be saved in
        to adjacent folder, whose name will be constructed as: output_file_name + "_files".
        
        :param path: Local path to output file.
        :param save_options: MHTML save options.'''
        ...
    
    @overload
    def save(self, url : aspose.html.Url, save_options : aspose.html.saving.MHTMLSaveOptions):
        '''Saves the document to local file specified by ``url``. All resources used in this document will be saved in
        to adjacent folder, whose name will be constructed as: output_file_name + "_files".
        
        :param url: Local URL to output file.
        :param save_options: MHTML save options.'''
        ...
    
    @overload
    def save(self, resource_handler : aspose.html.saving.resourcehandlers.ResourceHandler, save_options : aspose.html.saving.MHTMLSaveOptions):
        '''Saves the document content and resources using the :py:class:`aspose.html.saving.resourcehandlers.ResourceHandler`.
        
        :param resource_handler: The resource handler :py:class:`aspose.html.saving.resourcehandlers.ResourceHandler`.
        :param save_options: MHTML save options.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def create_element(self, local_name : str) -> aspose.html.dom.Element:
        '''Creates an element of the type specified. Note that the instance returned implements the Element interface, so attributes can be specified directly on the returned object.
        
        :param local_name: Name of the tag.
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    def create_element_ns(self, namespace_uri : str, qualified_name : str) -> aspose.html.dom.Element:
        '''Creates an element of the given qualified name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    def create_document_fragment(self) -> aspose.html.dom.DocumentFragment:
        '''Creates an empty DocumentFragment object.
        
        :returns: The :py:class:`aspose.html.dom.DocumentFragment`.'''
        ...
    
    def create_text_node(self, data : str) -> aspose.html.dom.Text:
        '''Creates a Text node given the specified string.
        
        :param data: The text data.
        :returns: The :py:class:`aspose.html.dom.Text`.'''
        ...
    
    def create_comment(self, data : str) -> aspose.html.dom.Comment:
        '''Creates a Comment node given the specified string.
        
        :param data: The comment data.
        :returns: The :py:class:`aspose.html.dom.Comment`.'''
        ...
    
    def create_cdata_section(self, data : str) -> aspose.html.dom.CDATASection:
        '''Creates a CDATASection node whose value is the specified string.
        
        :param data: The CDATA data.
        :returns: The :py:class:`aspose.html.dom.CDATASection`.'''
        ...
    
    def create_processing_instruction(self, target : str, data : str) -> aspose.html.dom.ProcessingInstruction:
        '''Creates a ProcessingInstruction node given the specified name and data strings.
        
        :param target: The target.
        :param data: The instruction data.
        :returns: The :py:class:`aspose.html.dom.ProcessingInstruction`.'''
        ...
    
    def create_attribute(self, local_name : str) -> aspose.html.dom.Attr:
        '''Creates an Attr of the given name.
        
        :param local_name: The attribute name.
        :returns: The :py:class:`aspose.html.dom.Attr`.'''
        ...
    
    def create_attribute_ns(self, namespace_uri : str, qualified_name : str) -> aspose.html.dom.Attr:
        '''Creates an attribute of the given qualified name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :returns: The :py:class:`aspose.html.dom.Attr`.'''
        ...
    
    def create_entity_reference(self, name : str) -> aspose.html.dom.EntityReference:
        '''Creates an EntityReference object. In addition, if the referenced entity is known, the child list of the EntityReference node is made the same as that of the corresponding Entity node.
        
        :param name: The entity name.
        :returns: The :py:class:`aspose.html.dom.EntityReference`.'''
        ...
    
    def create_document_type(self, name : str, public_id : str, system_id : str, internal_subset : str) -> aspose.html.dom.DocumentType:
        '''Creates a DocumentType node.
        
        :param name: The document type name.
        :param public_id: The public id.
        :param system_id: The system id.
        :param internal_subset: The internal subset.
        :returns: The :py:class:`aspose.html.dom.DocumentType`.'''
        ...
    
    def get_elements_by_tag_name(self, tagname : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the Elements in document order with a given tag name and are contained in the document.
        
        :param tagname: The tagname.
        :returns: Returns nodes.'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns nodes'''
        ...
    
    def get_element_by_id(self, element_id : str) -> aspose.html.dom.Element:
        '''Returns the Element that has an ID attribute with the given value. If no such element exists, this returns null. If more than one element has an ID attribute with that value, what is returned is undefined.
        
        :param element_id: The element id.
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The query selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched node.'''
        ...
    
    def import_node(self, imported_node : aspose.html.dom.Node, deep : bool) -> aspose.html.dom.Node:
        '''Imports a node from another document to this document, without altering or removing the source node from the original document; this method creates a new copy of the source node.
        
        :param imported_node: The imported node.
        :param deep: if set to ``true`` [deep].
        :returns: The :py:class:`aspose.html.dom.Node`.'''
        ...
    
    def create_event(self, event_type : str) -> aspose.html.dom.events.Event:
        '''Creates an :py:class:`aspose.html.dom.events.Event` of a type supported by the implementation.
        
        :param event_type: The eventType parameter specifies the type of :py:class:`aspose.html.dom.events.Event` interface to be created.
        :returns: The newly created :py:class:`aspose.html.dom.events.Event`'''
        ...
    
    def write(self, texts : List[str]):
        '''Write a string of text to a document stream opened by
        open(). Note that the function will produce a document
        which is not necessarily driven by a DTD and therefore might be
        produce an invalid result in the context of the document.
        
        :param texts: The string to be parsed into some structure in the
        document structure model.'''
        ...
    
    def write_ln(self, texts : List[str]):
        '''Write a string of text followed by a newline character to a document
        stream opened by open(). Note that the function will
        produce a document which is not necessarily driven by a DTD and
        therefore might be produce an invalid result in the context of the
        document
        
        :param texts: The string to be parsed into some structure in the
        document structure model.'''
        ...
    
    def create_expression(self, expression : str, resolver : aspose.html.dom.xpath.IXPathNSResolver) -> aspose.html.dom.xpath.IXPathExpression:
        '''Creates a parsed XPath expression with resolved namespaces. This is useful
        when an expression will be reused in an application since it makes it possible
        to compile the expression string into a more efficient internal form and
        preresolve all namespace prefixes which occur within the expression.
        
        :param expression: The XPath expression string to be parsed.
        :param resolver: The ``resolver`` permits translation of all prefixes,
        including the ``xml`` namespace prefix, within the XPath expression into
        appropriate namespace URIs. If this is specified as ``null``, any namespace
        prefix within the expression will result in :py:class:`aspose.html.dom.DOMException` being
        thrown with the code ``NAMESPACE_ERR``.
        :returns: The compiled form of the XPath expression.'''
        ...
    
    def create_ns_resolver(self, node_resolver : aspose.html.dom.Node) -> aspose.html.dom.xpath.IXPathNSResolver:
        '''Adapts any DOM node to resolve namespaces so that an XPath expression can be easily evaluated
        relative to the context of the node where it appeared within the document. This adapter works
        like the DOM Level 3 method ``lookupNamespaceURI`` on nodes in resolving the namespaceURI
        from a given prefix using the current information available in the node's hierarchy at the time
        lookupNamespaceURI is called, also correctly resolving the implicit xml prefix.
        
        :param node_resolver: The node to be used as a context for namespace resolution.
        :returns: :py:class:`aspose.html.dom.xpath.IXPathNSResolver` which resolves namespaces with respect to the definitions in scope for a specified node.'''
        ...
    
    def evaluate(self, expression : str, context_node : aspose.html.dom.Node, resolver : aspose.html.dom.xpath.IXPathNSResolver, type : aspose.html.dom.xpath.XPathResultType, result : any) -> aspose.html.dom.xpath.IXPathResult:
        '''Evaluates an XPath expression string and returns a result of the specified type if possible.
        
        :param expression: The XPath expression string to be parsed and evaluated.
        :param context_node: The context is context node for the evaluation of this XPath expression.
        :param resolver: The resolver permits translation of all prefixes, including the xml
        namespace prefix, within the XPath expression into appropriate namespace URIs.
        :param type: If a specific type is specified, then the result will be returned as the corresponding type.
        :param result: The result specifies a specific result object which may be reused and returned by this method.
        :returns: The result of the evaluation of the XPath expression.'''
        ...
    
    def render_to(self, device : aspose.html.rendering.IDevice):
        '''This method is used to print the contents of the current document to the specified device.
        
        :param device: The user device.'''
        ...
    
    def get_override_style(self, elt : aspose.html.dom.Element, pseudo_elt : str) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''This method is used to retrieve the override style declaration for a specified element and a specified pseudo-element.
        
        :param elt: The element whose style is to be modified. This parameter cannot be null.
        :param pseudo_elt: The pseudo-element or null if none.
        :returns: The override style declaration'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def context(self) -> aspose.html.dom.IBrowsingContext:
        '''Gets the current browsing context.'''
        ...
    
    @property
    def implementation(self) -> aspose.html.dom.IDOMImplementation:
        '''The DOMImplementation object that handles this document.'''
        ...
    
    @property
    def location(self) -> aspose.html.window.Location:
        '''The location of the document.'''
        ...
    
    @property
    def document_uri(self) -> str:
        ...
    
    @property
    def origin(self) -> str:
        '''Gets the document origin.'''
        ...
    
    @property
    def character_set(self) -> str:
        ...
    
    @property
    def charset(self) -> str:
        '''Gets the document's encoding.'''
        ...
    
    @property
    def input_encoding(self) -> str:
        ...
    
    @property
    def content_type(self) -> str:
        ...
    
    @property
    def ready_state(self) -> str:
        ...
    
    @property
    def doctype(self) -> aspose.html.dom.DocumentType:
        '''The Document Type Declaration associated with this document.'''
        ...
    
    @property
    def document_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements.'''
        ...
    
    @property
    def xml_standalone(self) -> bool:
        ...
    
    @xml_standalone.setter
    def xml_standalone(self, value : bool):
        ...
    
    @property
    def xml_version(self) -> str:
        ...
    
    @xml_version.setter
    def xml_version(self, value : str):
        ...
    
    @property
    def strict_error_checking(self) -> bool:
        ...
    
    @strict_error_checking.setter
    def strict_error_checking(self, value : bool):
        ...
    
    @property
    def default_view(self) -> aspose.html.window.IWindow:
        ...
    
    @property
    def style_sheets(self) -> aspose.html.dom.css.IStyleSheetList:
        ...
    
    @property
    def title(self) -> str:
        '''The title of a document as specified by the ``TITLE`` element
        in the head of the document.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The title of a document as specified by the ``TITLE`` element
        in the head of the document.'''
        ...
    
    @property
    def referrer(self) -> str:
        '''Returns the URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] of the page that linked to this page. The value is an
        empty string if the user navigated to the page directly (not through
        a link, but, for example, via a bookmark).'''
        ...
    
    @property
    def domain(self) -> str:
        '''The domain name of the server that served the document, or
        ``null`` if the server cannot be identified by a domain
        name.'''
        ...
    
    @property
    def body(self) -> aspose.html.HTMLElement:
        '''The element that contains the content for the document. In documents
        with ``BODY`` contents, returns the ``BODY``
        element. In frameset documents, this returns the outermost
        ``FRAMESET`` element.'''
        ...
    
    @body.setter
    def body(self, value : aspose.html.HTMLElement):
        '''The element that contains the content for the document. In documents
        with ``BODY`` contents, returns the ``BODY``
        element. In frameset documents, this returns the outermost
        ``FRAMESET`` element.'''
        ...
    
    @property
    def images(self) -> aspose.html.collections.HTMLCollection:
        '''A collection of all the ``IMG`` elements in a document. The
        behavior is limited to ``IMG`` elements for backwards
        compatibility. As suggested by [`HTML 4.01 <http://www.w3.org/TR/1999/REC-html401-19991224>`], to include images, authors may use
        the ``OBJECT`` element or the ``IMG`` element.
        Therefore, it is recommended not to use this attribute to find the
        images in the document but ``getElementsByTagName`` with
        HTML 4.01 or ``getElementsByTagNameNS`` with XHTML 1.0.'''
        ...
    
    @property
    def applets(self) -> aspose.html.collections.HTMLCollection:
        '''A collection of all the ``OBJECT`` elements that include
        applets and ``APPLET`` (deprecated) elements in a document.'''
        ...
    
    @property
    def links(self) -> aspose.html.collections.HTMLCollection:
        '''A collection of all ``AREA`` elements and anchor (
        ``A``) elements in a document with a value for the
        ``href`` attribute.'''
        ...
    
    @property
    def forms(self) -> aspose.html.collections.HTMLCollection:
        '''A collection of all the forms of a document.'''
        ...
    
    @property
    def anchors(self) -> aspose.html.collections.HTMLCollection:
        '''A collection of all the anchor (``A``) elements in a document
        with a value for the ``name`` attribute. For reasons of
        backward compatibility, the returned set of anchors only contains
        those anchors created with the ``name`` attribute, not those
        created with the ``id`` attribute. Note that in [`XHTML 1.0 <http://www.w3.org/TR/2002/REC-xhtml1-20020801>`], the
        ``name`` attribute (see section 4.10) has no semantics and
        is only present for legacy user agents: the ``id`` attribute
        is used instead. Users should prefer the iterator mechanisms provided
        by [`DOM Level 2 Traversal <http://www.w3.org/TR/2000/REC-DOM-Level-2-Traversal-Range-20001113>`] instead.'''
        ...
    
    ...

class HTMLElement(aspose.html.dom.Element):
    '''All HTML element interfaces derive from this class. Elements that only
    expose the HTML core attributes are represented by the base
    ``HTMLElement`` interface. These elements are as follows:
    special: SUB, SUP, SPAN, BDOfont: TT, I, B, U, S, STRIKE, BIG, SMALL
    phrase: EM, STRONG, DFN, CODE, SAMP, KBD, VAR, CITE, ACRONYM, ABBRlist:
    DD, DTNOFRAMES, NOSCRIPTADDRESS, CENTERThe ``style`` attribute
    of an HTML element is accessible through the
    ``ElementCSSInlineStyle`` interface which is defined in the CSS
    module [`DOM Level 2 Style Sheets and CSS <http://www.w3.org/TR/2000/REC-DOM-Level-2-Style-20001113>`].
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    ...

class HTMLFieldSetElement(HTMLElement):
    '''Organizes form controls into logical groups. See the FIELDSET element
    definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def form(self) -> aspose.html.HTMLFormElement:
        '''Returns the ``FORM`` element containing this control. Returns
        ``null`` if this control is not within the context of a
        form.'''
        ...
    
    ...

class HTMLFontElement(HTMLElement):
    '''Local change to font. See the FONT element definition in HTML 4.01. This
    element is deprecated in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def color(self) -> str:
        '''Font color. See the color attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @color.setter
    def color(self, value : str):
        '''Font color. See the color attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def face(self) -> str:
        '''Font face identifier. See the face attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @face.setter
    def face(self, value : str):
        '''Font face identifier. See the face attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def size(self) -> str:
        '''Font size. See the size attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @size.setter
    def size(self, value : str):
        '''Font size. See the size attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLFormElement(HTMLElement):
    '''The ``FORM`` element encompasses behavior similar to a collection
    and an element. It provides direct access to the contained form controls
    as well as the attributes of the form element. See the FORM element
    definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    def submit(self):
        '''Submits the form. It performs the same action as a submit button.'''
        ...
    
    def reset(self):
        '''Restores a form element's default values. It performs the same action
        as a reset button.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def elements(self) -> aspose.html.collections.HTMLCollection:
        '''Returns a collection of all form control elements in the form.'''
        ...
    
    @property
    def length(self) -> int:
        '''The number of form controls in the form.'''
        ...
    
    @property
    def name(self) -> str:
        '''Names the form.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''Names the form.'''
        ...
    
    @property
    def accept_charset(self) -> str:
        ...
    
    @accept_charset.setter
    def accept_charset(self, value : str):
        ...
    
    @property
    def action(self) -> str:
        '''Server-side form handler. See the action attribute definition in HTML 4.01.'''
        ...
    
    @action.setter
    def action(self, value : str):
        '''Server-side form handler. See the action attribute definition in HTML 4.01.'''
        ...
    
    @property
    def enctype(self) -> str:
        '''The content type of the submitted form, generally
        "application/x-www-form-urlencoded". See the enctype attribute
        definition in HTML 4.01. The onsubmit even handler is not guaranteed
        to be triggered when invoking this method. The behavior is
        inconsistent for historical reasons and authors should not rely on a
        particular one.'''
        ...
    
    @enctype.setter
    def enctype(self, value : str):
        '''The content type of the submitted form, generally
        "application/x-www-form-urlencoded". See the enctype attribute
        definition in HTML 4.01. The onsubmit even handler is not guaranteed
        to be triggered when invoking this method. The behavior is
        inconsistent for historical reasons and authors should not rely on a
        particular one.'''
        ...
    
    @property
    def method(self) -> str:
        '''HTTP method [`IETF RFC 2616 <http://www.ietf.org/rfc/rfc2616.txt>`] used to submit form. See the method attribute definition in HTML 4.01.'''
        ...
    
    @method.setter
    def method(self, value : str):
        '''HTTP method [`IETF RFC 2616 <http://www.ietf.org/rfc/rfc2616.txt>`] used to submit form. See the method attribute definition in HTML 4.01.'''
        ...
    
    @property
    def target(self) -> str:
        '''Frame to render the resource in. See the target attribute definition in
        HTML 4.01.'''
        ...
    
    @target.setter
    def target(self, value : str):
        '''Frame to render the resource in. See the target attribute definition in
        HTML 4.01.'''
        ...
    
    ...

class HTMLFrameElement(HTMLElement):
    '''Create a frame. See the FRAME element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def frame_border(self) -> str:
        ...
    
    @frame_border.setter
    def frame_border(self, value : str):
        ...
    
    @property
    def long_desc(self) -> str:
        ...
    
    @long_desc.setter
    def long_desc(self, value : str):
        ...
    
    @property
    def margin_height(self) -> str:
        ...
    
    @margin_height.setter
    def margin_height(self, value : str):
        ...
    
    @property
    def margin_width(self) -> str:
        ...
    
    @margin_width.setter
    def margin_width(self, value : str):
        ...
    
    @property
    def name(self) -> str:
        '''The frame name (object of the ``target`` attribute). See the
        name attribute definition in HTML 4.01.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''The frame name (object of the ``target`` attribute). See the
        name attribute definition in HTML 4.01.'''
        ...
    
    @property
    def no_resize(self) -> bool:
        ...
    
    @no_resize.setter
    def no_resize(self, value : bool):
        ...
    
    @property
    def scrolling(self) -> str:
        '''Specify whether or not the frame should have scrollbars. See the
        scrolling attribute definition in HTML 4.01.'''
        ...
    
    @scrolling.setter
    def scrolling(self, value : str):
        '''Specify whether or not the frame should have scrollbars. See the
        scrolling attribute definition in HTML 4.01.'''
        ...
    
    @property
    def src(self) -> str:
        '''A URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating the initial frame contents. See the src attribute
        definition in HTML 4.01.'''
        ...
    
    @src.setter
    def src(self, value : str):
        '''A URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating the initial frame contents. See the src attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def content_document(self) -> aspose.html.HTMLDocument:
        ...
    
    ...

class HTMLFrameSetElement(HTMLElement):
    '''Create a grid of frames. See the FRAMESET element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def cols(self) -> str:
        '''The number of columns of frames in the frameset. See the cols attribute
        definition in HTML 4.01.'''
        ...
    
    @cols.setter
    def cols(self, value : str):
        '''The number of columns of frames in the frameset. See the cols attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def rows(self) -> str:
        '''The number of rows of frames in the frameset. See the rows attribute
        definition in HTML 4.01.'''
        ...
    
    @rows.setter
    def rows(self, value : str):
        '''The number of rows of frames in the frameset. See the rows attribute
        definition in HTML 4.01.'''
        ...
    
    ...

class HTMLHRElement(HTMLElement):
    '''Create a horizontal rule. See the HR element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def align(self) -> str:
        '''Align the rule on the page. See the align attribute definition in HTML
        4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Align the rule on the page. See the align attribute definition in HTML
        4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def no_shade(self) -> bool:
        ...
    
    @no_shade.setter
    def no_shade(self, value : bool):
        ...
    
    @property
    def size(self) -> str:
        '''The height of the rule. See the size attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @size.setter
    def size(self, value : str):
        '''The height of the rule. See the size attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def width(self) -> str:
        '''The width of the rule. See the width attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @width.setter
    def width(self, value : str):
        '''The width of the rule. See the width attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLHeadElement(HTMLElement):
    '''Document head information. See the HEAD element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def profile(self) -> str:
        '''URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating a metadata profile. See the profile attribute
        definition in HTML 4.01.'''
        ...
    
    @profile.setter
    def profile(self, value : str):
        '''URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating a metadata profile. See the profile attribute
        definition in HTML 4.01.'''
        ...
    
    ...

class HTMLHeadingElement(HTMLElement):
    '''For the ``H1`` to ``H6`` elements. See the H1 element
    definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def align(self) -> str:
        '''Horizontal text alignment. See the align attribute definition in HTML
        4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Horizontal text alignment. See the align attribute definition in HTML
        4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLHtmlElement(HTMLElement):
    '''Root of an HTML document. See the HTML element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def version(self) -> str:
        '''Version information about the document's DTD. See the version attribute
        definition in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @version.setter
    def version(self, value : str):
        '''Version information about the document's DTD. See the version attribute
        definition in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLIFrameElement(HTMLElement):
    '''Inline subwindows. See the IFRAME element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def align(self) -> str:
        '''Aligns this object (vertically or horizontally) with respect to its
        surrounding text. See the align attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Aligns this object (vertically or horizontally) with respect to its
        surrounding text. See the align attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def frame_border(self) -> str:
        ...
    
    @frame_border.setter
    def frame_border(self, value : str):
        ...
    
    @property
    def height(self) -> str:
        '''Frame height. See the height attribute definition in HTML 4.01.'''
        ...
    
    @height.setter
    def height(self, value : str):
        '''Frame height. See the height attribute definition in HTML 4.01.'''
        ...
    
    @property
    def long_desc(self) -> str:
        ...
    
    @long_desc.setter
    def long_desc(self, value : str):
        ...
    
    @property
    def margin_height(self) -> str:
        ...
    
    @margin_height.setter
    def margin_height(self, value : str):
        ...
    
    @property
    def margin_width(self) -> str:
        ...
    
    @margin_width.setter
    def margin_width(self, value : str):
        ...
    
    @property
    def name(self) -> str:
        '''The frame name (object of the ``target`` attribute). See the
        name attribute definition in HTML 4.01.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''The frame name (object of the ``target`` attribute). See the
        name attribute definition in HTML 4.01.'''
        ...
    
    @property
    def scrolling(self) -> str:
        '''Specify whether or not the frame should have scrollbars. See the
        scrolling attribute definition in HTML 4.01.'''
        ...
    
    @scrolling.setter
    def scrolling(self, value : str):
        '''Specify whether or not the frame should have scrollbars. See the
        scrolling attribute definition in HTML 4.01.'''
        ...
    
    @property
    def src(self) -> str:
        '''A URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating the initial frame contents. See the src attribute
        definition in HTML 4.01.'''
        ...
    
    @src.setter
    def src(self, value : str):
        '''A URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating the initial frame contents. See the src attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def width(self) -> str:
        '''Frame width. See the width attribute definition in HTML 4.01.'''
        ...
    
    @width.setter
    def width(self, value : str):
        '''Frame width. See the width attribute definition in HTML 4.01.'''
        ...
    
    ...

class HTMLImageElement(HTMLElement):
    '''Embedded image. See the IMG element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def name(self) -> str:
        '''The name of the element (for backwards compatibility).'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''The name of the element (for backwards compatibility).'''
        ...
    
    @property
    def align(self) -> str:
        '''Aligns this object (vertically or horizontally) with respect to its
        surrounding text. See the align attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Aligns this object (vertically or horizontally) with respect to its
        surrounding text. See the align attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def alt(self) -> str:
        '''Alternate text for user agents not rendering the normal content of this
        element. See the alt attribute definition in HTML 4.01.'''
        ...
    
    @alt.setter
    def alt(self, value : str):
        '''Alternate text for user agents not rendering the normal content of this
        element. See the alt attribute definition in HTML 4.01.'''
        ...
    
    @property
    def border(self) -> str:
        '''Width of border around image. See the  border attribute definition in
        HTML 4.01. This attribute is deprecated in HTML 4.01. Note that the
        type of this attribute was ``DOMString`` in DOM Level 1 HTML [`DOM Level 1 <http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001>`]
        .'''
        ...
    
    @border.setter
    def border(self, value : str):
        '''Width of border around image. See the  border attribute definition in
        HTML 4.01. This attribute is deprecated in HTML 4.01. Note that the
        type of this attribute was ``DOMString`` in DOM Level 1 HTML [`DOM Level 1 <http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001>`]
        .'''
        ...
    
    @property
    def height(self) -> float:
        '''Height of the image in pixels. See the height attribute definition in
        HTML 4.01. Note that the type of this attribute was
        ``DOMString`` in DOM Level 1 HTML [`DOM Level 1 <http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001>`].
        @version DOM Level 2'''
        ...
    
    @height.setter
    def height(self, value : float):
        '''Height of the image in pixels. See the height attribute definition in
        HTML 4.01. Note that the type of this attribute was
        ``DOMString`` in DOM Level 1 HTML [`DOM Level 1 <http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001>`].
        @version DOM Level 2'''
        ...
    
    @property
    def hspace(self) -> int:
        '''Horizontal space to the left and right of this image in pixels. See the
        hspace attribute definition in HTML 4.01. This attribute is
        deprecated in HTML 4.01. Note that the type of this attribute was
        ``DOMString`` in DOM Level 1 HTML [`DOM Level 1 <http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001>`].
        @version DOM Level 2'''
        ...
    
    @hspace.setter
    def hspace(self, value : int):
        '''Horizontal space to the left and right of this image in pixels. See the
        hspace attribute definition in HTML 4.01. This attribute is
        deprecated in HTML 4.01. Note that the type of this attribute was
        ``DOMString`` in DOM Level 1 HTML [`DOM Level 1 <http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001>`].
        @version DOM Level 2'''
        ...
    
    @property
    def is_map(self) -> bool:
        ...
    
    @is_map.setter
    def is_map(self, value : bool):
        ...
    
    @property
    def long_desc(self) -> str:
        ...
    
    @long_desc.setter
    def long_desc(self, value : str):
        ...
    
    @property
    def src(self) -> str:
        '''URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating the source of this image. See the src attribute
        definition in HTML 4.01.'''
        ...
    
    @src.setter
    def src(self, value : str):
        '''URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating the source of this image. See the src attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def use_map(self) -> str:
        ...
    
    @use_map.setter
    def use_map(self, value : str):
        ...
    
    @property
    def vspace(self) -> int:
        '''Vertical space above and below this image in pixels. See the vspace
        attribute definition in HTML 4.01. This attribute is deprecated in
        HTML 4.01. Note that the type of this attribute was "DOMString" in
        DOM Level 1 HTML [`DOM Level 1 <http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001>`].
        @version DOM Level 2'''
        ...
    
    @vspace.setter
    def vspace(self, value : int):
        '''Vertical space above and below this image in pixels. See the vspace
        attribute definition in HTML 4.01. This attribute is deprecated in
        HTML 4.01. Note that the type of this attribute was "DOMString" in
        DOM Level 1 HTML [`DOM Level 1 <http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001>`].
        @version DOM Level 2'''
        ...
    
    @property
    def width(self) -> float:
        '''The width of the image in pixels. See the width attribute definition in
        HTML 4.01. Note that the type of this attribute was
        ``DOMString`` in DOM Level 1 HTML [`DOM Level 1 <http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001>`].
        @version DOM Level 2'''
        ...
    
    @width.setter
    def width(self, value : float):
        '''The width of the image in pixels. See the width attribute definition in
        HTML 4.01. Note that the type of this attribute was
        ``DOMString`` in DOM Level 1 HTML [`DOM Level 1 <http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001>`].
        @version DOM Level 2'''
        ...
    
    ...

class HTMLInputElement(HTMLElement):
    '''Form control.Depending upon the environment in which the page is being
    viewed, the value property may be read-only for the file upload input
    type. For the "password" input type, the actual value returned may be
    masked to prevent unauthorized use. See the INPUT element definition in [`HTML 4.01 <http://www.w3.org/TR/1999/REC-html401-19991224>`].
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def default_value(self) -> str:
        ...
    
    @default_value.setter
    def default_value(self, value : str):
        ...
    
    @property
    def default_checked(self) -> bool:
        ...
    
    @default_checked.setter
    def default_checked(self, value : bool):
        ...
    
    @property
    def form(self) -> aspose.html.HTMLFormElement:
        '''Returns the ``FORM`` element containing this control. Returns
        ``null`` if this control is not within the context of a
        form.'''
        ...
    
    @form.setter
    def form(self, value : aspose.html.HTMLFormElement):
        '''Returns the ``FORM`` element containing this control. Returns
        ``null`` if this control is not within the context of a
        form.'''
        ...
    
    @property
    def files(self) -> aspose.html.io.IFileList:
        '''The files IDL attribute allows scripts to access the element’s selected files.
        On getting, if the IDL attribute applies, it must return a FileList object that represents the current selected files.
        The same object must be returned until the list of selected files changes. If the IDL attribute does not apply, then it must instead return null.  [FILEAPI]'''
        ...
    
    @property
    def accept(self) -> str:
        '''A comma-separated list of content types that a server processing this
        form will handle correctly. See the accept attribute definition in
        HTML 4.01.'''
        ...
    
    @accept.setter
    def accept(self, value : str):
        '''A comma-separated list of content types that a server processing this
        form will handle correctly. See the accept attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def access_key(self) -> str:
        ...
    
    @access_key.setter
    def access_key(self, value : str):
        ...
    
    @property
    def align(self) -> str:
        '''Aligns this object (vertically or horizontally) with respect to its
        surrounding text. See the align attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Aligns this object (vertically or horizontally) with respect to its
        surrounding text. See the align attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def alt(self) -> str:
        '''Alternate text for user agents not rendering the normal content of this
        element. See the alt attribute definition in HTML 4.01.'''
        ...
    
    @alt.setter
    def alt(self, value : str):
        '''Alternate text for user agents not rendering the normal content of this
        element. See the alt attribute definition in HTML 4.01.'''
        ...
    
    @property
    def checked(self) -> bool:
        '''When the ``type`` attribute of the element has the value
        "radio" or "checkbox", this represents the current state of the form
        control, in an interactive user agent. Changes to this attribute
        change the state of the form control, but do not change the value of
        the HTML checked attribute of the INPUT element.During the handling
        of a click event on an input element with a type attribute that has
        the value "radio" or "checkbox", some implementations may change the
        value of this property before the event is being dispatched in the
        document. If the default action of the event is canceled, the value
        of the property may be changed back to its original value. This means
        that the value of this property during the handling of click events
        is implementation dependent.'''
        ...
    
    @checked.setter
    def checked(self, value : bool):
        '''When the ``type`` attribute of the element has the value
        "radio" or "checkbox", this represents the current state of the form
        control, in an interactive user agent. Changes to this attribute
        change the state of the form control, but do not change the value of
        the HTML checked attribute of the INPUT element.During the handling
        of a click event on an input element with a type attribute that has
        the value "radio" or "checkbox", some implementations may change the
        value of this property before the event is being dispatched in the
        document. If the default action of the event is canceled, the value
        of the property may be changed back to its original value. This means
        that the value of this property during the handling of click events
        is implementation dependent.'''
        ...
    
    @property
    def disabled(self) -> bool:
        '''The control is unavailable in this context. See the disabled attribute
        definition in HTML 4.01.'''
        ...
    
    @disabled.setter
    def disabled(self, value : bool):
        '''The control is unavailable in this context. See the disabled attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def list(self) -> str:
        '''The list attribute is used to identify an element that lists predefined options suggested to the user.
        If present, its value must be the ID of a datalist element in the same document.'''
        ...
    
    @list.setter
    def list(self, value : str):
        '''The list attribute is used to identify an element that lists predefined options suggested to the user.
        If present, its value must be the ID of a datalist element in the same document.'''
        ...
    
    @property
    def max_length(self) -> int:
        ...
    
    @max_length.setter
    def max_length(self, value : int):
        ...
    
    @property
    def name(self) -> str:
        '''Form control or object name when submitted with a form. See the name
        attribute definition in HTML 4.01.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''Form control or object name when submitted with a form. See the name
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def read_only(self) -> bool:
        ...
    
    @read_only.setter
    def read_only(self, value : bool):
        ...
    
    @property
    def size(self) -> int:
        '''Size information. The precise meaning is specific to each type of
        field. See the size attribute definition in HTML 4.01.
        @version DOM Level 2'''
        ...
    
    @size.setter
    def size(self, value : int):
        '''Size information. The precise meaning is specific to each type of
        field. See the size attribute definition in HTML 4.01.
        @version DOM Level 2'''
        ...
    
    @property
    def src(self) -> str:
        '''When the ``type`` attribute has the value "image", this
        attribute specifies the location of the image to be used to decorate
        the graphical submit button. See the src attribute definition in HTML
        4.01.'''
        ...
    
    @src.setter
    def src(self, value : str):
        '''When the ``type`` attribute has the value "image", this
        attribute specifies the location of the image to be used to decorate
        the graphical submit button. See the src attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def tab_index(self) -> int:
        ...
    
    @tab_index.setter
    def tab_index(self, value : int):
        ...
    
    @property
    def type(self) -> str:
        '''The type of control created (all lower case). See the type attribute definition in HTML 4.01. @version DOM Level 2'''
        ...
    
    @type.setter
    def type(self, value : str):
        '''The type of control created (all lower case). See the type attribute definition in HTML 4.01. @version DOM Level 2'''
        ...
    
    @property
    def use_map(self) -> str:
        ...
    
    @use_map.setter
    def use_map(self, value : str):
        ...
    
    @property
    def value(self) -> str:
        '''When the ``type`` attribute of the element has the value
        "text", "file" or "password", this represents the current contents of
        the corresponding form control, in an interactive user agent.
        Changing this attribute changes the contents of the form control, but
        does not change the value of the HTML value attribute of the element.
        When the ``type`` attribute of the element has the value
        "button", "hidden", "submit", "reset", "image", "checkbox" or
        "radio", this represents the HTML value attribute of the element. See
        the value attribute definition in HTML 4.01.'''
        ...
    
    @value.setter
    def value(self, value : str):
        '''When the ``type`` attribute of the element has the value
        "text", "file" or "password", this represents the current contents of
        the corresponding form control, in an interactive user agent.
        Changing this attribute changes the contents of the form control, but
        does not change the value of the HTML value attribute of the element.
        When the ``type`` attribute of the element has the value
        "button", "hidden", "submit", "reset", "image", "checkbox" or
        "radio", this represents the HTML value attribute of the element. See
        the value attribute definition in HTML 4.01.'''
        ...
    
    ...

class HTMLIsIndexElement(HTMLElement):
    '''This element is used for single-line text input. See the ISINDEX element
    definition in HTML 4.01. This element is deprecated in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def form(self) -> aspose.html.HTMLFormElement:
        '''Returns the     FORM
        element containing this control. Returns
        null
        if this control is not within the context of a
        form.'''
        ...
    
    @property
    def prompt(self) -> str:
        '''The prompt message. See the prompt attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @prompt.setter
    def prompt(self, value : str):
        '''The prompt message. See the prompt attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLLIElement(HTMLElement):
    '''List item. See the LI element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def type(self) -> str:
        '''List item bullet style. See the type attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @type.setter
    def type(self, value : str):
        '''List item bullet style. See the type attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def value(self) -> int:
        '''Reset sequence number when used in ``OL``. See the value
        attribute definition in HTML 4.01. This attribute is deprecated in
        HTML 4.01.'''
        ...
    
    @value.setter
    def value(self, value : int):
        '''Reset sequence number when used in ``OL``. See the value
        attribute definition in HTML 4.01. This attribute is deprecated in
        HTML 4.01.'''
        ...
    
    ...

class HTMLLabelElement(HTMLElement):
    '''Form field label text. See the LABEL element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def form(self) -> aspose.html.HTMLFormElement:
        '''Returns the ``FORM`` element containing this control. Returns
        ``null`` if this control is not within the context of a
        form.'''
        ...
    
    @property
    def access_key(self) -> str:
        ...
    
    @access_key.setter
    def access_key(self, value : str):
        ...
    
    ...

class HTMLLegendElement(HTMLElement):
    '''Provides a caption for a ``FIELDSET`` grouping. See the LEGEND
    element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def form(self) -> aspose.html.HTMLFormElement:
        '''Returns the ``FORM`` element containing this control. Returns
        ``null`` if this control is not within the context of a
        form.'''
        ...
    
    @property
    def access_key(self) -> str:
        ...
    
    @access_key.setter
    def access_key(self, value : str):
        ...
    
    @property
    def align(self) -> str:
        '''Text alignment relative to ``FIELDSET``. See the align
        attribute definition in HTML 4.01. This attribute is deprecated in
        HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Text alignment relative to ``FIELDSET``. See the align
        attribute definition in HTML 4.01. This attribute is deprecated in
        HTML 4.01.'''
        ...
    
    ...

class HTMLLinkElement(HTMLElement):
    '''The ``LINK`` element specifies a link to an external resource, and
    defines this document's relationship to that resource (or vice versa).
    See the LINK element definition in HTML 4.01 (see also the
    ``LinkStyle`` interface in the StyleSheet module [`DOM Level 2 Style Sheets and CSS <http://www.w3.org/TR/2000/REC-DOM-Level-2-Style-20001113>`]).
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def rel_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def disabled(self) -> bool:
        '''Enables/disables the link. This is currently only used for style sheet
        links, and may be used to activate or deactivate style sheets.'''
        ...
    
    @disabled.setter
    def disabled(self, value : bool):
        '''Enables/disables the link. This is currently only used for style sheet
        links, and may be used to activate or deactivate style sheets.'''
        ...
    
    @property
    def charset(self) -> str:
        '''The character encoding of the resource being linked to. See the charset
        attribute definition in HTML 4.01.'''
        ...
    
    @charset.setter
    def charset(self, value : str):
        '''The character encoding of the resource being linked to. See the charset
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def href(self) -> str:
        '''The URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] of the linked resource. See the href attribute definition in
        HTML 4.01.'''
        ...
    
    @href.setter
    def href(self, value : str):
        '''The URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] of the linked resource. See the href attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def hreflang(self) -> str:
        '''Language code of the linked resource. See the hreflang attribute
        definition in HTML 4.01.'''
        ...
    
    @hreflang.setter
    def hreflang(self, value : str):
        '''Language code of the linked resource. See the hreflang attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def media(self) -> str:
        '''Designed for use with one or more target media. See the media attribute
        definition in HTML 4.01.'''
        ...
    
    @media.setter
    def media(self, value : str):
        '''Designed for use with one or more target media. See the media attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def rel(self) -> str:
        '''Forward link type. See the rel attribute definition in HTML 4.01.'''
        ...
    
    @rel.setter
    def rel(self, value : str):
        '''Forward link type. See the rel attribute definition in HTML 4.01.'''
        ...
    
    @property
    def rev(self) -> str:
        '''Reverse link type. See the rev attribute definition in HTML 4.01.'''
        ...
    
    @rev.setter
    def rev(self, value : str):
        '''Reverse link type. See the rev attribute definition in HTML 4.01.'''
        ...
    
    @property
    def target(self) -> str:
        '''Frame to render the resource in. See the target attribute definition in
        HTML 4.01.'''
        ...
    
    @target.setter
    def target(self, value : str):
        '''Frame to render the resource in. See the target attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def type(self) -> str:
        '''Advisory content type. See the type attribute definition in HTML 4.01.'''
        ...
    
    @type.setter
    def type(self, value : str):
        '''Advisory content type. See the type attribute definition in HTML 4.01.'''
        ...
    
    @property
    def sheet(self) -> aspose.html.dom.css.IStyleSheet:
        '''Gets the associated style sheet.'''
        ...
    
    ...

class HTMLMapElement(HTMLElement):
    '''Client-side image map. See the MAP element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def areas(self) -> aspose.html.collections.HTMLCollection:
        '''The list of areas defined for the image map.'''
        ...
    
    @property
    def name(self) -> str:
        '''Names the map (for use with ``usemap``). See the name
        attribute definition in HTML 4.01.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''Names the map (for use with ``usemap``). See the name
        attribute definition in HTML 4.01.'''
        ...
    
    ...

class HTMLMenuElement(HTMLElement):
    '''Menu list. See the MENU element definition in HTML 4.01. This element is
    deprecated in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def compact(self) -> bool:
        '''Reduce spacing between list items. See the compact attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @compact.setter
    def compact(self, value : bool):
        '''Reduce spacing between list items. See the compact attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLMetaElement(HTMLElement):
    '''This contains generic meta-information about the document. See the META
    element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def content(self) -> str:
        '''Associated information. See the content attribute definition in HTML
        4.01.'''
        ...
    
    @content.setter
    def content(self, value : str):
        '''Associated information. See the content attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def http_equiv(self) -> str:
        ...
    
    @http_equiv.setter
    def http_equiv(self, value : str):
        ...
    
    @property
    def name(self) -> str:
        '''Meta information name. See the name attribute definition in HTML 4.01.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''Meta information name. See the name attribute definition in HTML 4.01.'''
        ...
    
    @property
    def scheme(self) -> str:
        '''Select form of content. See the scheme attribute definition in HTML
        4.01.'''
        ...
    
    @scheme.setter
    def scheme(self, value : str):
        '''Select form of content. See the scheme attribute definition in HTML
        4.01.'''
        ...
    
    ...

class HTMLModElement(HTMLElement):
    '''Notice of modification to part of a document. See the INS and DEL element
    definitions in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def cite(self) -> str:
        '''A URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating a document that describes the reason for the change.
        See the cite attribute definition in HTML 4.01.'''
        ...
    
    @cite.setter
    def cite(self, value : str):
        '''A URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating a document that describes the reason for the change.
        See the cite attribute definition in HTML 4.01.'''
        ...
    
    @property
    def date_time(self) -> str:
        ...
    
    @date_time.setter
    def date_time(self, value : str):
        ...
    
    ...

class HTMLNoScriptElement(HTMLElement):
    '''Script statements. See the NOSCRIPT element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    ...

class HTMLOListElement(HTMLElement):
    '''Ordered list. See the OL element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def compact(self) -> bool:
        '''Reduce spacing between list items. See the compact attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @compact.setter
    def compact(self, value : bool):
        '''Reduce spacing between list items. See the compact attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def start(self) -> int:
        '''Starting sequence number. See the start attribute definition in HTML
        4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @start.setter
    def start(self, value : int):
        '''Starting sequence number. See the start attribute definition in HTML
        4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def type(self) -> str:
        '''Numbering style. See the type attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @type.setter
    def type(self, value : str):
        '''Numbering style. See the type attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLObjectElement(HTMLElement):
    '''Generic embedded object.In principle, all properties on the object element
    are read-write but in some environments some properties may be read-only
    once the underlying object is instantiated. See the OBJECT element
    definition in [`HTML 4.01 <http://www.w3.org/TR/1999/REC-html401-19991224>`].
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def form(self) -> aspose.html.HTMLFormElement:
        '''Returns the ``FORM`` element containing this control. Returns ``null`` if this control is not within the context of a form.'''
        ...
    
    @form.setter
    def form(self, value : aspose.html.HTMLFormElement):
        '''Returns the ``FORM`` element containing this control. Returns ``null`` if this control is not within the context of a form.'''
        ...
    
    @property
    def code(self) -> str:
        '''Applet class file. See the ``code`` attribute for HTMLAppletElement.'''
        ...
    
    @code.setter
    def code(self, value : str):
        '''Applet class file. See the ``code`` attribute for HTMLAppletElement.'''
        ...
    
    @property
    def align(self) -> str:
        '''Aligns this object (vertically or horizontally) with respect to its surrounding text. See the align attribute definition in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Aligns this object (vertically or horizontally) with respect to its surrounding text. See the align attribute definition in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def archive(self) -> str:
        '''Space-separated list of archives. See the archive attribute definition in HTML 4.01.'''
        ...
    
    @archive.setter
    def archive(self, value : str):
        '''Space-separated list of archives. See the archive attribute definition in HTML 4.01.'''
        ...
    
    @property
    def border(self) -> str:
        '''Width of border around the object. See the border attribute definition in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @border.setter
    def border(self, value : str):
        '''Width of border around the object. See the border attribute definition in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def code_base(self) -> str:
        ...
    
    @code_base.setter
    def code_base(self, value : str):
        ...
    
    @property
    def code_type(self) -> str:
        ...
    
    @code_type.setter
    def code_type(self, value : str):
        ...
    
    @property
    def class_id(self) -> str:
        ...
    
    @class_id.setter
    def class_id(self, value : str):
        ...
    
    @property
    def data(self) -> str:
        '''A URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] specifying the location of the object's data. See the data
        attribute definition in HTML 4.01.'''
        ...
    
    @data.setter
    def data(self, value : str):
        '''A URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] specifying the location of the object's data. See the data
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def declare(self) -> bool:
        '''Declare (for future reference), but do not instantiate, this object.
        See the declare attribute definition in HTML 4.01.'''
        ...
    
    @declare.setter
    def declare(self, value : bool):
        '''Declare (for future reference), but do not instantiate, this object.
        See the declare attribute definition in HTML 4.01.'''
        ...
    
    @property
    def height(self) -> str:
        '''Override height. See the height attribute definition in HTML 4.01.'''
        ...
    
    @height.setter
    def height(self, value : str):
        '''Override height. See the height attribute definition in HTML 4.01.'''
        ...
    
    @property
    def hspace(self) -> int:
        '''Horizontal space, in pixels, to the left and right of this image,
        applet, or object. See the hspace attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @hspace.setter
    def hspace(self, value : int):
        '''Horizontal space, in pixels, to the left and right of this image,
        applet, or object. See the hspace attribute definition in HTML 4.01.
        This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def name(self) -> str:
        '''Form control or object name when submitted with a form. See the name
        attribute definition in HTML 4.01.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''Form control or object name when submitted with a form. See the name
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def standby(self) -> str:
        '''Message to render while loading the object. See the standby attribute
        definition in HTML 4.01.'''
        ...
    
    @standby.setter
    def standby(self, value : str):
        '''Message to render while loading the object. See the standby attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def tab_index(self) -> int:
        ...
    
    @tab_index.setter
    def tab_index(self, value : int):
        ...
    
    @property
    def type(self) -> str:
        '''Content type for data downloaded via ``data`` attribute. See
        the type attribute definition in HTML 4.01.'''
        ...
    
    @type.setter
    def type(self, value : str):
        '''Content type for data downloaded via ``data`` attribute. See
        the type attribute definition in HTML 4.01.'''
        ...
    
    @property
    def use_map(self) -> str:
        ...
    
    @use_map.setter
    def use_map(self, value : str):
        ...
    
    @property
    def vspace(self) -> int:
        '''Vertical space, in pixels, above and below this image, applet, or object. See the vspace attribute definition in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @vspace.setter
    def vspace(self, value : int):
        '''Vertical space, in pixels, above and below this image, applet, or object. See the vspace attribute definition in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def width(self) -> str:
        '''Override width. See the width attribute definition in HTML 4.01.'''
        ...
    
    @width.setter
    def width(self, value : str):
        '''Override width. See the width attribute definition in HTML 4.01.'''
        ...
    
    ...

class HTMLOptGroupElement(HTMLElement):
    '''Group options together in logical subdivisions. See the OPTGROUP element
    definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def disabled(self) -> bool:
        '''The control is unavailable in this context. See the disabled attribute
        definition in HTML 4.01.'''
        ...
    
    @disabled.setter
    def disabled(self, value : bool):
        '''The control is unavailable in this context. See the disabled attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def label(self) -> str:
        '''Assigns a label to this option group. See the label attribute definition
        in HTML 4.01.'''
        ...
    
    @label.setter
    def label(self, value : str):
        '''Assigns a label to this option group. See the label attribute definition
        in HTML 4.01.'''
        ...
    
    ...

class HTMLOptionElement(HTMLElement):
    '''A selectable choice. See the OPTION element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def form(self) -> aspose.html.HTMLFormElement:
        '''Returns the ``FORM`` element containing this control. Returns
        ``null`` if this control is not within the context of a
        form.'''
        ...
    
    @property
    def default_selected(self) -> bool:
        ...
    
    @default_selected.setter
    def default_selected(self, value : bool):
        ...
    
    @property
    def text(self) -> str:
        '''The text contained within the option element.'''
        ...
    
    @property
    def index(self) -> int:
        '''The index of this ``OPTION`` in its parent ``SELECT``
        , starting from 0.
        @version DOM Level 2'''
        ...
    
    @property
    def disabled(self) -> bool:
        '''The control is unavailable in this context. See the disabled attribute definition in HTML 4.01.'''
        ...
    
    @disabled.setter
    def disabled(self, value : bool):
        '''The control is unavailable in this context. See the disabled attribute definition in HTML 4.01.'''
        ...
    
    @property
    def label(self) -> str:
        '''Option label for use in hierarchical menus. See the label attribute definition in HTML 4.01.'''
        ...
    
    @label.setter
    def label(self, value : str):
        '''Option label for use in hierarchical menus. See the label attribute definition in HTML 4.01.'''
        ...
    
    @property
    def selected(self) -> bool:
        '''Represents the current state of the corresponding form control, in an
        interactive user agent. Changing this attribute changes the state of
        the form control, but does not change the value of the HTML selected
        attribute of the element.'''
        ...
    
    @selected.setter
    def selected(self, value : bool):
        '''Represents the current state of the corresponding form control, in an
        interactive user agent. Changing this attribute changes the state of
        the form control, but does not change the value of the HTML selected
        attribute of the element.'''
        ...
    
    @property
    def value(self) -> str:
        '''The current form control value. See the value attribute definition in HTML 4.01.'''
        ...
    
    @value.setter
    def value(self, value : str):
        '''The current form control value. See the value attribute definition in HTML 4.01.'''
        ...
    
    ...

class HTMLParagraphElement(HTMLElement):
    '''Paragraphs. See the P element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def align(self) -> str:
        '''Horizontal text alignment. See the align attribute definition in HTML
        4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Horizontal text alignment. See the align attribute definition in HTML
        4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLParamElement(HTMLElement):
    '''Parameters fed to the ``OBJECT`` element. See the PARAM element
    definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def name(self) -> str:
        '''The name of a run-time parameter. See the name attribute definition in
        HTML 4.01.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''The name of a run-time parameter. See the name attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def type(self) -> str:
        '''Content type for the ``value`` attribute when
        ``valuetype`` has the value "ref". See the type attribute
        definition in HTML 4.01.'''
        ...
    
    @type.setter
    def type(self, value : str):
        '''Content type for the ``value`` attribute when
        ``valuetype`` has the value "ref". See the type attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def value(self) -> str:
        '''The value of a run-time parameter. See the value attribute definition
        in HTML 4.01.'''
        ...
    
    @value.setter
    def value(self, value : str):
        '''The value of a run-time parameter. See the value attribute definition
        in HTML 4.01.'''
        ...
    
    @property
    def value_type(self) -> str:
        ...
    
    @value_type.setter
    def value_type(self, value : str):
        ...
    
    ...

class HTMLPreElement(HTMLElement):
    '''Preformatted text. See the PRE element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def width(self) -> int:
        '''Fixed width for content. See the width attribute definition in HTML
        4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @width.setter
    def width(self, value : int):
        '''Fixed width for content. See the width attribute definition in HTML
        4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLQuoteElement(HTMLElement):
    '''For the ``Q`` and ``BLOCKQUOTE`` elements. See the Q
    element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def cite(self) -> str:
        '''A URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating a source document or message. See the cite attribute
        definition in HTML 4.01.'''
        ...
    
    @cite.setter
    def cite(self, value : str):
        '''A URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating a source document or message. See the cite attribute
        definition in HTML 4.01.'''
        ...
    
    ...

class HTMLScriptElement(HTMLElement):
    '''Script statements. See the SCRIPT element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def text(self) -> str:
        '''The script content of the element.'''
        ...
    
    @text.setter
    def text(self, value : str):
        '''The script content of the element.'''
        ...
    
    @property
    def event(self) -> str:
        '''Reserved for future use.'''
        ...
    
    @event.setter
    def event(self, value : str):
        '''Reserved for future use.'''
        ...
    
    @property
    def charset(self) -> str:
        '''The character encoding of the linked resource. See the charset
        attribute definition in HTML 4.01.'''
        ...
    
    @charset.setter
    def charset(self, value : str):
        '''The character encoding of the linked resource. See the charset
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def defer(self) -> bool:
        '''Indicates that the user agent can defer processing of the script. See
        the defer attribute definition in HTML 4.01.'''
        ...
    
    @defer.setter
    def defer(self, value : bool):
        '''Indicates that the user agent can defer processing of the script. See
        the defer attribute definition in HTML 4.01.'''
        ...
    
    @property
    def src(self) -> str:
        '''URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating an external script. See the src attribute definition
        in HTML 4.01.'''
        ...
    
    @src.setter
    def src(self, value : str):
        '''URI [`IETF RFC 2396 <http://www.ietf.org/rfc/rfc2396.txt>`] designating an external script. See the src attribute definition
        in HTML 4.01.'''
        ...
    
    @property
    def type(self) -> str:
        '''The content type of the script language. See the type attribute
        definition in HTML 4.01.'''
        ...
    
    @type.setter
    def type(self, value : str):
        '''The content type of the script language. See the type attribute
        definition in HTML 4.01.'''
        ...
    
    ...

class HTMLSelectElement(HTMLElement):
    '''The select element allows the selection of an option. The contained options
    can be directly accessed through the select element as a collection. See
    the SELECT element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def type(self) -> str:
        '''The type of this form control. This is the string "select-multiple" when the multiple attribute is ``true`` and the string "select-one" when ``false``.'''
        ...
    
    @property
    def selected_index(self) -> int:
        ...
    
    @selected_index.setter
    def selected_index(self, value : int):
        ...
    
    @property
    def value(self) -> str:
        '''The current form control value (i.e. the value of the currently
        selected option), if multiple options are selected this is the value
        of the first selected option.'''
        ...
    
    @value.setter
    def value(self, value : str):
        '''The current form control value (i.e. the value of the currently
        selected option), if multiple options are selected this is the value
        of the first selected option.'''
        ...
    
    @property
    def length(self) -> int:
        '''The number of options in this ``SELECT``.
        @version DOM Level 2'''
        ...
    
    @length.setter
    def length(self, value : int):
        '''The number of options in this ``SELECT``.
        @version DOM Level 2'''
        ...
    
    @property
    def form(self) -> aspose.html.HTMLFormElement:
        '''The number of options in this ``SELECT``.'''
        ...
    
    @property
    def options(self) -> aspose.html.IHTMLOptionsCollection:
        '''The collection of ``OPTION`` elements contained by this
        element.
        @version DOM Level 2'''
        ...
    
    @property
    def disabled(self) -> bool:
        '''The control is unavailable in this context. See the disabled attribute
        definition in HTML 4.01.'''
        ...
    
    @disabled.setter
    def disabled(self, value : bool):
        '''The control is unavailable in this context. See the disabled attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def multiple(self) -> bool:
        '''If true, multiple ``OPTION`` elements may be selected in this ``SELECT``. See the multiple attribute definition in HTML 4.01.'''
        ...
    
    @multiple.setter
    def multiple(self, value : bool):
        '''If true, multiple ``OPTION`` elements may be selected in this ``SELECT``. See the multiple attribute definition in HTML 4.01.'''
        ...
    
    @property
    def name(self) -> str:
        '''Form control or object name when submitted with a form. See the name
        attribute definition in HTML 4.01.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''Form control or object name when submitted with a form. See the name
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def size(self) -> int:
        '''Number of visible rows. See the size attribute definition in HTML 4.01.'''
        ...
    
    @size.setter
    def size(self, value : int):
        '''Number of visible rows. See the size attribute definition in HTML 4.01.'''
        ...
    
    @property
    def tab_index(self) -> int:
        ...
    
    @tab_index.setter
    def tab_index(self, value : int):
        ...
    
    ...

class HTMLStyleElement(HTMLElement):
    '''Style information. See the STYLE element definition in HTML 4.01, the CSS
    module [`DOM Level 2 Style Sheets and CSS <http://www.w3.org/TR/2000/REC-DOM-Level-2-Style-20001113>`] and the ``LinkStyle`` interface in the StyleSheets
    module [`DOM Level 2 Style Sheets and CSS <http://www.w3.org/TR/2000/REC-DOM-Level-2-Style-20001113>`].
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def disabled(self) -> bool:
        '''Enables/disables the style sheet.'''
        ...
    
    @disabled.setter
    def disabled(self, value : bool):
        '''Enables/disables the style sheet.'''
        ...
    
    @property
    def media(self) -> str:
        '''Designed for use with one or more target media. See the media attribute
        definition in HTML 4.01.'''
        ...
    
    @media.setter
    def media(self, value : str):
        '''Designed for use with one or more target media. See the media attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def type(self) -> str:
        '''The content type of the style sheet language. See the type attribute
        definition in HTML 4.01.'''
        ...
    
    @type.setter
    def type(self, value : str):
        '''The content type of the style sheet language. See the type attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def sheet(self) -> aspose.html.dom.css.IStyleSheet:
        '''Gets the associated style sheet.'''
        ...
    
    ...

class HTMLTableCaptionElement(HTMLElement):
    '''Table caption See the CAPTION element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def align(self) -> str:
        '''Caption alignment with respect to the table. See the align attribute
        definition in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Caption alignment with respect to the table. See the align attribute
        definition in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLTableCellElement(HTMLElement):
    '''The object used to represent the ``TH`` and ``TD``
    elements. See the TD element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def cell_index(self) -> int:
        ...
    
    @property
    def abbr(self) -> str:
        '''Abbreviation for header cells. See the abbr attribute definition in
        HTML 4.01.'''
        ...
    
    @abbr.setter
    def abbr(self, value : str):
        '''Abbreviation for header cells. See the abbr attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def align(self) -> str:
        '''Horizontal alignment of data in cell. See the align attribute definition
        in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Horizontal alignment of data in cell. See the align attribute definition
        in HTML 4.01.'''
        ...
    
    @property
    def axis(self) -> str:
        '''Names group of related headers. See the axis attribute definition in
        HTML 4.01.'''
        ...
    
    @axis.setter
    def axis(self, value : str):
        '''Names group of related headers. See the axis attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def bg_color(self) -> str:
        ...
    
    @bg_color.setter
    def bg_color(self, value : str):
        ...
    
    @property
    def ch(self) -> str:
        '''Alignment character for cells in a column. See the char attribute
        definition in HTML 4.01.'''
        ...
    
    @ch.setter
    def ch(self, value : str):
        '''Alignment character for cells in a column. See the char attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def ch_off(self) -> str:
        ...
    
    @ch_off.setter
    def ch_off(self, value : str):
        ...
    
    @property
    def col_span(self) -> int:
        ...
    
    @col_span.setter
    def col_span(self, value : int):
        ...
    
    @property
    def headers(self) -> str:
        '''List of ``id`` attribute values for header cells. See the
        headers attribute definition in HTML 4.01.'''
        ...
    
    @headers.setter
    def headers(self, value : str):
        '''List of ``id`` attribute values for header cells. See the
        headers attribute definition in HTML 4.01.'''
        ...
    
    @property
    def height(self) -> str:
        '''Cell height. See the height attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @height.setter
    def height(self, value : str):
        '''Cell height. See the height attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def no_wrap(self) -> bool:
        ...
    
    @no_wrap.setter
    def no_wrap(self, value : bool):
        ...
    
    @property
    def row_span(self) -> int:
        ...
    
    @row_span.setter
    def row_span(self, value : int):
        ...
    
    @property
    def scope(self) -> str:
        '''Scope covered by header cells. See the scope attribute definition in
        HTML 4.01.'''
        ...
    
    @scope.setter
    def scope(self, value : str):
        '''Scope covered by header cells. See the scope attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def v_align(self) -> str:
        ...
    
    @v_align.setter
    def v_align(self, value : str):
        ...
    
    @property
    def width(self) -> str:
        '''Cell width. See the width attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @width.setter
    def width(self, value : str):
        '''Cell width. See the width attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLTableColElement(HTMLElement):
    '''Regroups the ``COL`` and ``COLGROUP`` elements. See the
    COL element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def align(self) -> str:
        '''Horizontal alignment of cell data in column. See the align attribute
        definition in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Horizontal alignment of cell data in column. See the align attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def ch(self) -> str:
        '''Alignment character for cells in a column. See the char attribute
        definition in HTML 4.01.'''
        ...
    
    @ch.setter
    def ch(self, value : str):
        '''Alignment character for cells in a column. See the char attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def ch_off(self) -> str:
        ...
    
    @ch_off.setter
    def ch_off(self, value : str):
        ...
    
    @property
    def span(self) -> int:
        '''Indicates the number of columns in a group or affected by a grouping.
        See the span attribute definition in HTML 4.01.'''
        ...
    
    @span.setter
    def span(self, value : int):
        '''Indicates the number of columns in a group or affected by a grouping.
        See the span attribute definition in HTML 4.01.'''
        ...
    
    @property
    def v_align(self) -> str:
        ...
    
    @v_align.setter
    def v_align(self, value : str):
        ...
    
    @property
    def width(self) -> str:
        '''Default column width. See the width attribute definition in HTML 4.01.'''
        ...
    
    @width.setter
    def width(self, value : str):
        '''Default column width. See the width attribute definition in HTML 4.01.'''
        ...
    
    ...

class HTMLTableElement(HTMLElement):
    '''The create* and delete* methods on the table allow authors to construct and
    modify tables. [`HTML 4.01 <http://www.w3.org/TR/1999/REC-html401-19991224>`] specifies that only one of each of the
    ``CAPTION``, ``THEAD``, and ``TFOOT`` elements
    may exist in a table. Therefore, if one exists, and the createTHead() or
    createTFoot() method is called, the method returns the existing THead or
    TFoot element. See the TABLE element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    def create_t_head(self) -> aspose.html.dom.Element:
        '''Create a table header row or return an existing one.
        
        :returns: A new table header element (``THEAD``).'''
        ...
    
    def delete_t_head(self):
        '''Delete the header from the table, if one exists.'''
        ...
    
    def create_t_foot(self) -> aspose.html.dom.Element:
        '''Create a table footer row or return an existing one.
        
        :returns: A footer element (``TFOOT``).'''
        ...
    
    def delete_t_foot(self):
        '''Delete the footer from the table, if one exists.'''
        ...
    
    def create_caption(self) -> aspose.html.dom.Element:
        '''Create a new table caption object or return an existing one.
        
        :returns: A ``CAPTION`` element.'''
        ...
    
    def delete_caption(self):
        '''Delete the table caption, if one exists.'''
        ...
    
    def insert_row(self, index : int) -> aspose.html.dom.Node:
        '''Insert a new empty row in the table. The new row is inserted
        immediately before and in the same section as the current
        ``index``th row in the table. If ``index`` is -1 or
        equal to the number of rows, the new row is appended. In addition,
        when the table is empty the row is inserted into a ``TBODY``
        which is created and inserted into the table.A table row cannot be
        empty according to [`HTML 4.01 <http://www.w3.org/TR/1999/REC-html401-19991224>`].
        
        :param index: The row number where to insert a new row. This index
        starts from 0 and is relative to the logical order (not document
        order) of all the rows contained inside the table.
        :returns: The newly created row.'''
        ...
    
    def delete_row(self, index : int):
        '''Delete a table row.
        
        :param index: The index of the row to be deleted. This index starts
        from 0 and is relative to the logical order (not document order) of
        all the rows contained inside the table. If the index is -1 the
        last row in the table is deleted.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def caption(self) -> aspose.html.HTMLTableCaptionElement:
        '''Returns the table's ``CAPTION``, or void if none exists.
        @version DOM Level 2'''
        ...
    
    @property
    def t_head(self) -> aspose.html.HTMLTableSectionElement:
        ...
    
    @property
    def t_foot(self) -> aspose.html.HTMLTableSectionElement:
        ...
    
    @property
    def rows(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the table's ``TFOOT``, or ``null`` if none
        exists.'''
        ...
    
    @property
    def t_bodies(self) -> aspose.html.collections.HTMLCollection:
        ...
    
    @property
    def align(self) -> str:
        '''Specifies the table's position with respect to the rest of the
        document. See the align attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Specifies the table's position with respect to the rest of the
        document. See the align attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def bg_color(self) -> str:
        ...
    
    @bg_color.setter
    def bg_color(self, value : str):
        ...
    
    @property
    def border(self) -> str:
        '''The width of the border around the table. See the border attribute
        definition in HTML 4.01.'''
        ...
    
    @border.setter
    def border(self, value : str):
        '''The width of the border around the table. See the border attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def cell_padding(self) -> str:
        ...
    
    @cell_padding.setter
    def cell_padding(self, value : str):
        ...
    
    @property
    def cell_spacing(self) -> str:
        ...
    
    @cell_spacing.setter
    def cell_spacing(self, value : str):
        ...
    
    @property
    def frame(self) -> str:
        '''Specifies which external table borders to render. See the frame
        attribute definition in HTML 4.01.'''
        ...
    
    @frame.setter
    def frame(self, value : str):
        '''Specifies which external table borders to render. See the frame
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def rules(self) -> str:
        '''Specifies which internal table borders to render. See the rules
        attribute definition in HTML 4.01.'''
        ...
    
    @rules.setter
    def rules(self, value : str):
        '''Specifies which internal table borders to render. See the rules
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def summary(self) -> str:
        '''Description about the purpose or structure of a table. See the summary
        attribute definition in HTML 4.01.'''
        ...
    
    @summary.setter
    def summary(self, value : str):
        '''Description about the purpose or structure of a table. See the summary
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def width(self) -> str:
        '''Specifies the desired table width. See the width attribute definition
        in HTML 4.01.'''
        ...
    
    @width.setter
    def width(self, value : str):
        '''Specifies the desired table width. See the width attribute definition
        in HTML 4.01.'''
        ...
    
    ...

class HTMLTableRowElement(HTMLElement):
    '''A row in a table. See the TR element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    def insert_cell(self, index : int) -> aspose.html.HTMLElement:
        '''Insert an empty ``TD`` cell into this row. If
        ``index`` is -1 or equal to the number of cells, the new
        cell is appended.
        
        :param index: The place to insert the cell, starting from 0.
        :returns: The newly created cell.'''
        ...
    
    def delete_cell(self, index : int):
        '''Delete a cell from the current row.
        
        :param index: The index of the cell to delete, starting from 0. If the
        index is -1 the last cell in the row is deleted.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def row_index(self) -> int:
        ...
    
    @property
    def section_row_index(self) -> int:
        ...
    
    @property
    def cells(self) -> aspose.html.collections.HTMLCollection:
        '''The collection of cells in this row.
        @version DOM Level 2'''
        ...
    
    @property
    def align(self) -> str:
        '''Horizontal alignment of data within cells of this row. See the align
        attribute definition in HTML 4.01.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Horizontal alignment of data within cells of this row. See the align
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def bg_color(self) -> str:
        ...
    
    @bg_color.setter
    def bg_color(self, value : str):
        ...
    
    @property
    def ch(self) -> str:
        '''Alignment character for cells in a column. See the char attribute
        definition in HTML 4.01.'''
        ...
    
    @ch.setter
    def ch(self, value : str):
        '''Alignment character for cells in a column. See the char attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def ch_off(self) -> str:
        ...
    
    @ch_off.setter
    def ch_off(self, value : str):
        ...
    
    @property
    def v_align(self) -> str:
        ...
    
    @v_align.setter
    def v_align(self, value : str):
        ...
    
    ...

class HTMLTableSectionElement(HTMLElement):
    '''The ``THEAD``, ``TFOOT``, and ``TBODY``
    elements.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    def insert_row(self, index : int) -> aspose.html.HTMLElement:
        '''Insert a row into this section. The new row is inserted immediately
        before the current ``index``th row in this section. If
        ``index`` is -1 or equal to the number of rows in this
        section, the new row is appended.
        
        :param index: The row number where to insert a new row. This index
        starts from 0 and is relative only to the rows contained inside
        this section, not all the rows in the table.
        :returns: The newly created row.'''
        ...
    
    def delete_row(self, index : int):
        '''Delete a row from this section.
        
        :param index: The index of the row to be deleted, or -1 to delete the
        last row. This index starts from 0 and is relative only to the rows
        contained inside this section, not all the rows in the table.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def align(self) -> str:
        '''Horizontal alignment of data in cells. See the ``align``
        attribute for HTMLTheadElement for details.'''
        ...
    
    @align.setter
    def align(self, value : str):
        '''Horizontal alignment of data in cells. See the ``align``
        attribute for HTMLTheadElement for details.'''
        ...
    
    @property
    def ch(self) -> str:
        '''Alignment character for cells in a column. See the char attribute
        definition in HTML 4.01.'''
        ...
    
    @ch.setter
    def ch(self, value : str):
        '''Alignment character for cells in a column. See the char attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def ch_off(self) -> str:
        ...
    
    @ch_off.setter
    def ch_off(self, value : str):
        ...
    
    @property
    def v_align(self) -> str:
        ...
    
    @v_align.setter
    def v_align(self, value : str):
        ...
    
    @property
    def rows(self) -> aspose.html.collections.HTMLCollection:
        '''The collection of rows in this table section.'''
        ...
    
    ...

class HTMLTemplateElement(HTMLElement):
    '''The template element'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def content(self) -> aspose.html.dom.DocumentFragment:
        '''Gets the instance of the :py:class:`aspose.html.dom.DocumentFragment`.'''
        ...
    
    ...

class HTMLTextAreaElement(HTMLElement):
    '''Multi-line text field. See the TEXTAREA element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def default_value(self) -> str:
        ...
    
    @default_value.setter
    def default_value(self, value : str):
        ...
    
    @property
    def form(self) -> aspose.html.HTMLFormElement:
        '''Returns the ``FORM`` element containing this control. Returns
        ``null`` if this control is not within the context of a
        form.'''
        ...
    
    @property
    def access_key(self) -> str:
        ...
    
    @access_key.setter
    def access_key(self, value : str):
        ...
    
    @property
    def cols(self) -> int:
        '''Width of control (in characters). See the cols attribute definition in
        HTML 4.01.'''
        ...
    
    @cols.setter
    def cols(self, value : int):
        '''Width of control (in characters). See the cols attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def disabled(self) -> bool:
        '''The control is unavailable in this context. See the disabled attribute
        definition in HTML 4.01.'''
        ...
    
    @disabled.setter
    def disabled(self, value : bool):
        '''The control is unavailable in this context. See the disabled attribute
        definition in HTML 4.01.'''
        ...
    
    @property
    def name(self) -> str:
        '''Form control or object name when submitted with a form. See the name
        attribute definition in HTML 4.01.'''
        ...
    
    @name.setter
    def name(self, value : str):
        '''Form control or object name when submitted with a form. See the name
        attribute definition in HTML 4.01.'''
        ...
    
    @property
    def read_only(self) -> bool:
        ...
    
    @read_only.setter
    def read_only(self, value : bool):
        ...
    
    @property
    def rows(self) -> int:
        '''Number of text rows. See the rows attribute definition in HTML 4.01.'''
        ...
    
    @rows.setter
    def rows(self, value : int):
        '''Number of text rows. See the rows attribute definition in HTML 4.01.'''
        ...
    
    @property
    def tab_index(self) -> int:
        ...
    
    @tab_index.setter
    def tab_index(self, value : int):
        ...
    
    @property
    def type(self) -> str:
        '''The type of this form control. This the string "textarea".'''
        ...
    
    @property
    def value(self) -> str:
        '''Represents the current contents of the corresponding form control, in
        an interactive user agent. Changing this attribute changes the
        contents of the form control, but does not change the contents of the
        element. If the entirety of the data can not fit into a single
        ``DOMString``, the implementation may truncate the data.'''
        ...
    
    @value.setter
    def value(self, value : str):
        '''Represents the current contents of the corresponding form control, in
        an interactive user agent. Changing this attribute changes the
        contents of the form control, but does not change the contents of the
        element. If the entirety of the data can not fit into a single
        ``DOMString``, the implementation may truncate the data.'''
        ...
    
    ...

class HTMLTitleElement(HTMLElement):
    '''The title element. See the TITLE element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    ...

class HTMLUListElement(HTMLElement):
    '''Unordered list. See the UL element definition in HTML 4.01.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    @property
    def compact(self) -> bool:
        '''Reduce spacing between list items. See the compact attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @compact.setter
    def compact(self, value : bool):
        '''Reduce spacing between list items. See the compact attribute definition
        in HTML 4.01. This attribute is deprecated in HTML 4.01.'''
        ...
    
    @property
    def type(self) -> str:
        '''Bullet style. See the type attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    @type.setter
    def type(self, value : str):
        '''Bullet style. See the type attribute definition in HTML 4.01. This
        attribute is deprecated in HTML 4.01.'''
        ...
    
    ...

class HTMLUnknownElement(HTMLElement):
    '''The Unknown html element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.html.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.html.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.html.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.html.dom.events.IEventListener` is removed from an :py:class:`aspose.html.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.html.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.html.dom.events.IEventListener` parameter indicates the :py:class:`aspose.html.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.html.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.html.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.html.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.html.dom.events.Event.prevent_default`.
        If :py:func:`aspose.html.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.html.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.html.dom.Node, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.html.dom.Node) -> aspose.html.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.html.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.html.dom.Attr) -> aspose.html.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.html.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.html.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.html.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.html.dom.ShadowRootMode) -> aspose.html.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.html.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.html.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.html.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.html.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.html.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.html.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def class_list(self) -> aspose.html.collections.DOMTokenList:
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.html.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.html.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.html.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.html.dom.ShadowRoot:
        ...
    
    @property
    def title(self) -> str:
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @title.setter
    def title(self, value : str):
        '''The element's advisory title. See the title attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def lang(self) -> str:
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @lang.setter
    def lang(self, value : str):
        '''Language code defined in RFC 1766. See the lang attribute definition in
        HTML 4.01.'''
        ...
    
    @property
    def dir(self) -> str:
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @dir.setter
    def dir(self, value : str):
        '''Specifies the base direction of directionally neutral text and the
        directionality of tables. See the dir attribute definition in HTML
        4.01.'''
        ...
    
    @property
    def style(self) -> aspose.html.dom.css.ICSSStyleDeclaration:
        '''Represents a style attribute that allows author to directly apply style information to specific element.'''
        ...
    
    ...

class IConfigurationBuilder:
    '''Represents a Configuration object builder.'''
    
    ...

class IDocumentFragmentElement:
    '''Represents common interface for all Document Fragment elements.'''
    
    @property
    def content(self) -> aspose.html.dom.DocumentFragment:
        '''Gets the instance of the :py:class:`aspose.html.dom.DocumentFragment`.'''
        ...
    
    ...

class IHTMLFormElement:
    '''Represents a base interface that should be implemented by HTML Form Elements.'''
    
    @property
    def elements(self) -> aspose.html.collections.HTMLCollection:
        '''Gets the collection of the child form elements.'''
        ...
    
    ...

class IHTMLOptionsCollection:
    '''An ``HTMLOptionsCollection`` is a list of nodes representing HTML
    option element. An individual node may be accessed by either ordinal
    index or the node's ``name`` or ``id`` attributes.
    Collections in the HTML DOM are assumed to be live meaning that they are
    automatically updated when the underlying document is changed.
    
    See also the `Document object Model (DOM) Level 2 HTML Specification <http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109>`.
    @since DOM Level 2'''
    
    def named_item(self, name : str) -> aspose.html.dom.Element:
        '''Method returns the indexth item in the collection.
        http://www.w3.org/TR/DOM-Level-2-HTML/html.html#HTMLOptionsCollection-namedItem
        
        :param name: The element name.
        :returns: Returns node.'''
        ...
    
    @property
    def length(self) -> int:
        '''The number of nodes in the list.'''
        ...
    
    def __getitem__(self, key : int) -> aspose.html.dom.Element:
        '''Method returns the indexth item in the collection. If index is greater than or equal to the number of nodes in the list, this returns null.
        http://www.w3.org/TR/DOM-Level-2-HTML/html.html#HTMLOptionsCollection-namedItem'''
        ...
    
    ...

class IUrlSearchParams:
    '''Provides methods to work with URLs query string.'''
    
    def append(self, name : str, value : str):
        '''Appends a new name-value pair whose name is ``name`` and value is ``value``.
        
        :param name: Name of the new name-value pair.
        :param value: Value of the new name-value pair.'''
        ...
    
    def delete(self, name : str):
        '''Removes all name-value pairs whose name is ``name``.
        
        :param name: Key which will be used to find name-value pairs.'''
        ...
    
    def get(self, name : str) -> str:
        '''Returns value of the first name-value pair whose name is ``name``.
        
        :param name: Key which will be used to find name-value pair.
        :returns: Value of the first name-value pair whose name is ``name`` or null
        if there is none.'''
        ...
    
    def get_all(self, name : str) -> List[str]:
        '''Returns all values whose name is ``name``.
        
        :param name: Key which will be used to find name-value pair.
        :returns: List containing all values whose name is ``name``.'''
        ...
    
    def has(self, name : str) -> bool:
        '''Checks if there is a name-value pair whose name is ``name`` in list.
        
        :param name: Key which will be used to find name-value pair.
        :returns: ``True`` if there is a name-value pair whose name is ``name``
        in list, and ``false`` otherwise.'''
        ...
    
    def set(self, name : str, value : str):
        '''Sets value of the first found name-value pair to the specified value and removes the others.
        If no name-value pairs with the specified name are found, new one will be appended to the list.
        
        :param name: Key which will be used to find name-value pairs.
        :param value: Value which will be set.'''
        ...
    
    def sort(self):
        '''Sorts all name-value pairs, if any, by their names.'''
        ...
    
    ...

class Int16Array(TypedArray):
    '''Represents an array of twos-complement 16-bit signed integers in the platform byte order.'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    @property
    def buffer(self) -> aspose.html.ArrayBuffer:
        '''Gets the ArrayBuffer referenced by this instance.'''
        ...
    
    @property
    def byte_length(self) -> int:
        ...
    
    @property
    def byte_offset(self) -> int:
        ...
    
    @property
    def length(self) -> int:
        '''Gets the length of a typed array.'''
        ...
    
    @classmethod
    @property
    def BYTES_PER_ELEMENT(cls) -> byte:
        '''The property represents the size in bytes of each element in an typed array.'''
        ...
    
    def __getitem__(self, key : int) -> int:
        '''Gets or sets the :py:class:`int` at the specified index.'''
        ...
    
    def __setitem__(self, key : int, value : int):
        ...
    
    ...

class Int32Array(TypedArray):
    '''Represents an array of twos-complement 32-bit signed integers in the platform byte order.'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    @property
    def buffer(self) -> aspose.html.ArrayBuffer:
        '''Gets the ArrayBuffer referenced by this instance.'''
        ...
    
    @property
    def byte_length(self) -> int:
        ...
    
    @property
    def byte_offset(self) -> int:
        ...
    
    @property
    def length(self) -> int:
        '''Gets the length of a typed array.'''
        ...
    
    @classmethod
    @property
    def BYTES_PER_ELEMENT(cls) -> byte:
        '''The property represents the size in bytes of each element in an typed array.'''
        ...
    
    def __getitem__(self, key : int) -> int:
        '''Gets or sets the :py:class:`int` at the specified index.'''
        ...
    
    def __setitem__(self, key : int, value : int):
        ...
    
    ...

class Int8Array(TypedArray):
    '''Represents an array of twos-complement 8-bit signed integers.'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    @property
    def buffer(self) -> aspose.html.ArrayBuffer:
        '''Gets the ArrayBuffer referenced by this instance.'''
        ...
    
    @property
    def byte_length(self) -> int:
        ...
    
    @property
    def byte_offset(self) -> int:
        ...
    
    @property
    def length(self) -> int:
        '''Gets the length of a typed array.'''
        ...
    
    @classmethod
    @property
    def BYTES_PER_ELEMENT(cls) -> byte:
        '''The property represents the size in bytes of each element in an typed array.'''
        ...
    
    def __getitem__(self, key : int) -> sbyte:
        '''Gets or sets the :py:class:`int` at the specified index.'''
        ...
    
    def __setitem__(self, key : int, value : sbyte):
        ...
    
    ...

class License:
    '''Provides methods to license the component.'''
    
    @overload
    def set_license(self, license_name : str):
        '''Licenses the component.
        
        :param license_name: Can be a full or short file name.
        Use an empty string to switch to evaluation mode.'''
        ...
    
    @overload
    def set_license(self, stream : io.RawIOBase):
        '''Licenses the component.
        
        :param stream: A stream that contains the license.'''
        ...
    
    ...

class Metered:
    '''Provides methods to set metered key.'''
    
    def set_metered_key(self, public_key : str, private_key : str):
        '''Sets metered public and private key.
        If you purchase metered license, when start application, this API should be called, normally, this is enough.
        However, if always fail to upload consumption data and exceed 24 hours, the license will be set to evaluation status,
        to avoid such case, you should regularly check the license status, if it is evaluation status, call this API again.
        
        :param public_key: public key
        :param private_key: private key'''
        ...
    
    @staticmethod
    def get_consumption_quantity() -> float:
        '''Gets consumption file size
        
        :returns: consumption quantity'''
        ...
    
    @staticmethod
    def get_consumption_credit() -> float:
        '''Gets consumption credit
        
        :returns: consumption quantity'''
        ...
    
    @staticmethod
    def is_metered_licensed() -> bool:
        '''Check whether metered is licensed
        
        :returns: True or false'''
        ...
    
    ...

class MimeType:
    '''Represents an Internet Media Types'''
    
    def equals(self, other : aspose.html.MimeType) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        ...
    
    @staticmethod
    def from_file_extension(file_name : str) -> aspose.html.MimeType:
        '''Creates a new MIME type based on file extension.
        
        :param file_name: The name of the file.
        :returns: The new instance of MIME type'''
        ...
    
    @property
    def type(self) -> str:
        '''Gets the media type.'''
        ...
    
    @property
    def sub_type(self) -> str:
        ...
    
    ...

class PlatformException:
    '''Represents the base class for all exceptions that may occur during the application execution.'''
    
    ...

class TypedArray(aspose.html.dom.DOMObject):
    '''TypedArray objects present an array-like view of an underlying binary data buffer.'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    @property
    def buffer(self) -> aspose.html.ArrayBuffer:
        '''Gets the ArrayBuffer referenced by this instance.'''
        ...
    
    @property
    def byte_length(self) -> int:
        ...
    
    @property
    def byte_offset(self) -> int:
        ...
    
    @property
    def length(self) -> int:
        '''Gets the length of a typed array.'''
        ...
    
    ...

class Uint16Array(TypedArray):
    '''Represents an array of twos-complement 16-bit unsigned integers in the platform byte order.'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    @property
    def buffer(self) -> aspose.html.ArrayBuffer:
        '''Gets the ArrayBuffer referenced by this instance.'''
        ...
    
    @property
    def byte_length(self) -> int:
        ...
    
    @property
    def byte_offset(self) -> int:
        ...
    
    @property
    def length(self) -> int:
        '''Gets the length of a typed array.'''
        ...
    
    @classmethod
    @property
    def BYTES_PER_ELEMENT(cls) -> byte:
        '''The property represents the size in bytes of each element in an typed array.'''
        ...
    
    def __getitem__(self, key : int) -> int:
        '''Gets or sets the :py:class:`int` at the specified index.'''
        ...
    
    def __setitem__(self, key : int, value : int):
        ...
    
    ...

class Uint32Array(TypedArray):
    '''Represents an array of twos-complement 32-bit unsigned integers in the platform byte order.'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    @property
    def buffer(self) -> aspose.html.ArrayBuffer:
        '''Gets the ArrayBuffer referenced by this instance.'''
        ...
    
    @property
    def byte_length(self) -> int:
        ...
    
    @property
    def byte_offset(self) -> int:
        ...
    
    @property
    def length(self) -> int:
        '''Gets the length of a typed array.'''
        ...
    
    @classmethod
    @property
    def BYTES_PER_ELEMENT(cls) -> byte:
        '''The property represents the size in bytes of each element in an typed array.'''
        ...
    
    def __getitem__(self, key : int) -> int:
        '''Gets or sets the :py:class:`int` at the specified index.'''
        ...
    
    def __setitem__(self, key : int, value : int):
        ...
    
    ...

class Uint8Array(TypedArray):
    '''Represents an array of twos-complement 8-bit unsigned  integers.'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    @property
    def buffer(self) -> aspose.html.ArrayBuffer:
        '''Gets the ArrayBuffer referenced by this instance.'''
        ...
    
    @property
    def byte_length(self) -> int:
        ...
    
    @property
    def byte_offset(self) -> int:
        ...
    
    @property
    def length(self) -> int:
        '''Gets the length of a typed array.'''
        ...
    
    @classmethod
    @property
    def BYTES_PER_ELEMENT(cls) -> byte:
        '''The property represents the size in bytes of each element in an typed array.'''
        ...
    
    def __getitem__(self, key : int) -> byte:
        '''Gets or sets the :py:class:`int` at the specified index.'''
        ...
    
    def __setitem__(self, key : int, value : byte):
        ...
    
    ...

class Uint8ClampedArray(TypedArray):
    '''Represents an array of 8-bit unsigned integers clamped to 0-255; if you specified a value that is out of the range of [0,255], 0 or 255 will be set instead;'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    @property
    def buffer(self) -> aspose.html.ArrayBuffer:
        '''Gets the ArrayBuffer referenced by this instance.'''
        ...
    
    @property
    def byte_length(self) -> int:
        ...
    
    @property
    def byte_offset(self) -> int:
        ...
    
    @property
    def length(self) -> int:
        '''Gets the length of a typed array.'''
        ...
    
    @classmethod
    @property
    def BYTES_PER_ELEMENT(cls) -> byte:
        '''The property represents the size in bytes of each element in an typed array.'''
        ...
    
    def __getitem__(self, key : int) -> byte:
        '''Gets or sets the :py:class:`int` at the specified index.'''
        ...
    
    def __setitem__(self, key : int, value : byte):
        ...
    
    ...

class Url(aspose.html.dom.DOMObject):
    '''Provides an object representation of a universal identifier (URL).'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def to_json(self) -> str:
        '''Returns a :py:class:`str` that represents this instance.
        
        :returns: A :py:class:`str` that represents this instance.'''
        ...
    
    @property
    def origin(self) -> str:
        '''Gets a string representation for the specified URL origin.'''
        ...
    
    @property
    def username(self) -> str:
        '''Gets a string representation for the specified URL username.'''
        ...
    
    @username.setter
    def username(self, value : str):
        '''Sets a string representation for the specified URL username.'''
        ...
    
    @property
    def password(self) -> str:
        '''Gets a string representation for the specified URL password.'''
        ...
    
    @password.setter
    def password(self, value : str):
        '''Sets a string representation for the specified URL password.'''
        ...
    
    @property
    def protocol(self) -> str:
        '''Gets a string representation for the specified URL schema.'''
        ...
    
    @protocol.setter
    def protocol(self, value : str):
        '''Sets a string representation for the specified URL schema.'''
        ...
    
    @property
    def host(self) -> str:
        '''Gets a string representation for the specified URL host.'''
        ...
    
    @host.setter
    def host(self, value : str):
        '''Sets a string representation for the specified URL host.'''
        ...
    
    @property
    def hostname(self) -> str:
        '''Gets a string representation for the specified URL hostname.'''
        ...
    
    @hostname.setter
    def hostname(self, value : str):
        '''Sets a string representation for the specified URL hostname.'''
        ...
    
    @property
    def port(self) -> str:
        '''Gets a string representation for the specified URL port.'''
        ...
    
    @port.setter
    def port(self, value : str):
        '''Sets a string representation for the specified URL port.'''
        ...
    
    @property
    def pathname(self) -> str:
        '''Gets a string representation for the specified URL path.'''
        ...
    
    @pathname.setter
    def pathname(self, value : str):
        '''Sets a string representation for the specified URL path.'''
        ...
    
    @property
    def search(self) -> str:
        '''Gets a string representation for the specified URL search segment.'''
        ...
    
    @search.setter
    def search(self, value : str):
        '''Sets a string representation for the specified URL search segment.'''
        ...
    
    @property
    def hash(self) -> str:
        '''Gets a string representation for the specified URL hash segment.'''
        ...
    
    @hash.setter
    def hash(self, value : str):
        '''Sets a string representation for the specified URL hash segment.'''
        ...
    
    @property
    def search_params(self) -> aspose.html.IUrlSearchParams:
        ...
    
    @property
    def href(self) -> str:
        '''Gets a serialized representation for the specified URL instance.'''
        ...
    
    @href.setter
    def href(self, value : str):
        '''Sets a serialized representation for the specified URL instance.'''
        ...
    
    ...

class Sandbox:
    '''A sandboxing flag set is a set of zero or more of the following flags, which are used to restrict the abilities that potentially untrusted resources.'''
    
    @classmethod
    @property
    def NONE(cls) -> Sandbox:
        '''No flag is set, every sandbox feature is accepted'''
        ...
    
    @classmethod
    @property
    def NAVIGATION(cls) -> Sandbox:
        '''This flag prevents content from navigating browsing contexts other than the sandboxed browsing context itself (or browsing contexts further nested inside it), auxiliary browsing contexts (which are protected by the sandboxed auxiliary navigation browsing context flag defined next), and the top-level browsing context (which is protected by the sandboxed top-level navigation browsing context flag defined below).
        If the sandboxed auxiliary navigation browsing context flag is not set, then in certain cases the restrictions nonetheless allow popups (new top-level browsing contexts) to be opened. These browsing contexts always have one permitted sandboxed navigator, set when the browsing context is created, which allows the browsing context that created them to actually navigate them. (Otherwise, the sandboxed navigation browsing context flag would prevent them from being navigated even if they were opened.'''
        ...
    
    @classmethod
    @property
    def AUXILIARY_NAVIGATION(cls) -> Sandbox:
        '''This flag prevents content from creating new auxiliary browsing contexts, e.g. using the target attribute, or the window.open() method.'''
        ...
    
    @classmethod
    @property
    def TOP_LEVEL_NAVIGATION(cls) -> Sandbox:
        '''This flag prevents content from navigating their top-level browsing context and prevents content from closing their top-level browsing context.
        When the sandboxed top-level navigation browsing context flag is not set, content can navigate its top-level browsing context, but other browsing contexts are still protected by the sandboxed navigation browsing context flag and possibly the sandboxed auxiliary navigation browsing context flag.'''
        ...
    
    @classmethod
    @property
    def PLUGINS(cls) -> Sandbox:
        '''This flag prevents content from instantiating plugins, whether using the embed element, the object element, the applet element, or through navigation of a nested browsing context, unless those plugins can be secured.'''
        ...
    
    @classmethod
    @property
    def ORIGIN(cls) -> Sandbox:
        '''This flag forces content into a unique origin, thus preventing it from accessing other content from the same origin.'''
        ...
    
    @classmethod
    @property
    def FORMS(cls) -> Sandbox:
        '''This flag blocks form submission.'''
        ...
    
    @classmethod
    @property
    def POINTER_LOCK(cls) -> Sandbox:
        '''This flag disables the Pointer Lock API.'''
        ...
    
    @classmethod
    @property
    def SCRIPTS(cls) -> Sandbox:
        '''This flag blocks script execution.'''
        ...
    
    @classmethod
    @property
    def AUTOMATIC_FEATURES(cls) -> Sandbox:
        '''This flag blocks features that trigger automatically, such as automatically playing a video or automatically focusing a form control.'''
        ...
    
    @classmethod
    @property
    def FULLSCREEN(cls) -> Sandbox:
        '''This flag prevents content from using the requestFullscreen() method.'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_DOMAIN(cls) -> Sandbox:
        '''This flag prevents content from using the document.domain feature to change the effective script origin.'''
        ...
    
    @classmethod
    @property
    def IMAGES(cls) -> Sandbox:
        '''This flag disables image loading.'''
        ...
    
    ...

